@@ -37,7 +37,7 @@ $lang['btn_update']            = 'Актуализиране';
 $lang['btn_delete']            = 'Изтриване';
 $lang['btn_back']              = 'Назад';
 $lang['btn_backlink']          = 'Обратни препратки';
-$lang['btn_backtomedia']       = 'Назад към избора на медиен файл';
+$lang['btn_backtomedia']       = 'Назад към избора на файл';
 $lang['btn_subscribe']         = 'Абонаменти';
 $lang['btn_profile']           = 'Профил';
 $lang['btn_reset']             = 'Изчистване';
@@ -47,6 +47,8 @@ $lang['btn_recover']           = 'Възстановяване на чернов
 $lang['btn_draftdel']          = 'Изтриване на чернова';
 $lang['btn_revert']            = 'Възстановяване';
 $lang['btn_register']          = 'Регистриране';
+$lang['btn_apply']             = 'Прилагане';
+$lang['btn_media']             = 'Диспечер на файлове';
 $lang['loggedinas']            = 'Вписани сте като';
 $lang['user']                  = 'Потребител';
 $lang['pass']                  = 'Парола';
@@ -91,7 +93,7 @@ $lang['txt_filename']          = 'Качи като (незадължителн
 $lang['txt_overwrt']           = 'Презапиши съществуващите файлове';
 $lang['lockedby']              = 'В момента е заключена от';
 $lang['lockexpire']            = 'Ще бъде отключена на';
-$lang['willexpire']            = 'Страницата ще бъде отключена за редактиране след минута.\nЗа предотвратяване на конфликти, ползвайте бутона "Преглед", за рестартиране на брояча за заключване.';
+$lang['js']['willexpire']      = 'Страницата ще бъде отключена за редактиране след минута.\nЗа предотвратяване на конфликти, ползвайте бутона "Преглед", за рестартиране на брояча за заключване.';
 $lang['js']['notsavedyet']     = 'Незаписаните промени ще бъдат загубени. Желаете ли да продължите?';
 $lang['js']['searchmedia']     = 'Търсене на файлове';
 $lang['js']['keepopen']        = 'Без затваряне на прозореца след избор';
@@ -122,11 +124,21 @@ $lang['js']['nosmblinks']      = 'Връзките към Windows shares раб
 $lang['js']['linkwiz']         = 'Помощник за препратки';
 $lang['js']['linkto']          = 'Препратка към: ';
 $lang['js']['del_confirm']     = 'Да бъдат ли изтрити избраните елементи?';
-$lang['js']['mu_btn']          = 'Качване на няколко файла наведнъж';
+$lang['js']['restore_confirm'] = 'Наистина ли желаете да бъде възстановена тази версия?';
+$lang['js']['media_diff']      = 'Преглед на разликите:';
+$lang['js']['media_diff_both'] = 'Един до друг';
+$lang['js']['media_diff_opacity'] = 'Наслагване (и прозиране)';
+$lang['js']['media_diff_portions'] = 'По половинка';
+$lang['js']['media_select']    = 'Изберете файлове...';
+$lang['js']['media_upload_btn'] = 'Качване';
+$lang['js']['media_done_btn']  = 'Готово';
+$lang['js']['media_drop']      = 'Влачете и пуснете файливе тук, за да бъдат качени';
+$lang['js']['media_cancel']    = 'премахване';
+$lang['js']['media_overwrt']   = 'Презапиши съществуващите файлове';
 $lang['rssfailed']             = 'Възникна грешка при получаването на емисията: ';
 $lang['nothingfound']          = 'Нищо не е открито.';
-$lang['mediaselect']           = 'Медийни файлове';
-$lang['fileupload']            = 'Качване на медийни файлове';
+$lang['mediaselect']           = 'Файлове';
+$lang['fileupload']            = 'Качване на файлове';
 $lang['uploadsucc']            = 'Качването е успешно';
 $lang['uploadfail']            = 'Качването се провали. Може би поради грешни права?';
 $lang['uploadwrong']           = 'Качването е отказано. Файлово разширение е забранено!';
@@ -177,6 +189,10 @@ $lang['mail_changed']          = 'променена страница: ';
 $lang['mail_subscribe_list']   = 'променени страници в именно пространство: ';
 $lang['mail_new_user']         = 'нов потребител: ';
 $lang['mail_upload']           = 'качен файл: ';
+$lang['changes_type']          = 'Преглед на променените';
+$lang['pages_changes']         = 'Страници';
+$lang['media_changes']         = 'Файлове';
+$lang['both_changes']          = 'Страници и файлове';
 $lang['qb_bold']               = 'Удебелен текст';
 $lang['qb_italic']             = 'Курсив текст';
 $lang['qb_underl']             = 'Подчертан текст';
@@ -217,6 +233,9 @@ $lang['img_copyr']             = 'Авторско право';
 $lang['img_format']            = 'Формат';
 $lang['img_camera']            = 'Фотоапарат';
 $lang['img_keywords']          = 'Ключови думи';
+$lang['img_width']             = 'Ширина';
+$lang['img_height']            = 'Височина';
+$lang['img_manager']           = 'Преглед в диспечера на файлове';
 $lang['subscr_subscribe_success'] = '%s е добавен към списъка с абониралите се за %s';
 $lang['subscr_subscribe_error'] = 'Грешка при добавянето на %s към списъка с абониралите се за %s';
 $lang['subscr_subscribe_noaddress'] = 'Добавянето ви към списъка с абонати не е възможно поради липсата на свързан адрес (на ел. поща) с профила ви.';
@@ -257,22 +276,6 @@ $lang['i_pol1']                = 'Публично Wiki (всеки може д
 $lang['i_pol2']                = 'Затворено Wiki (само регистрирани четат, пишат и качват)';
 $lang['i_retry']               = 'Повторен опит';
 $lang['i_license']             = 'Моля, изберете лиценз под който желаете да публикувате съдържанието:';
-$lang['mu_intro']              = 'От тук можете да качите няколко файла наведнъж. Натиснете бутона "Избиране", изберете файлове и натиснете "Качване".
-';
-$lang['mu_gridname']           = 'Име на файла';
-$lang['mu_gridsize']           = 'Големина';
-$lang['mu_gridstat']           = 'Състояние';
-$lang['mu_namespace']          = 'Именно пространство';
-$lang['mu_browse']             = 'Избиране';
-$lang['mu_toobig']             = 'прекалено голям';
-$lang['mu_ready']              = 'готов за качване';
-$lang['mu_done']               = 'качен';
-$lang['mu_fail']               = 'неуспешно качване';
-$lang['mu_authfail']           = 'приключила сесия';
-$lang['mu_progress']           = '@PCT@% качен';
-$lang['mu_filetypes']          = 'Позволени файлови разширения';
-$lang['mu_info']               = 'качени файла.';
-$lang['mu_lasterr']            = 'Последна грешка:';
 $lang['recent_global']         = 'В момента преглеждате промените в именно пространство <b>%s</b>. Може да прегледате и <a href="%s">промените в цялото Wiki</a>.';
 $lang['years']                 = 'преди %d години';
 $lang['months']                = 'преди %d месеца';
@@ -282,3 +285,27 @@ $lang['hours']                 = 'преди %d часа';
 $lang['minutes']               = 'преди %d минути';
 $lang['seconds']               = 'преди %d секунди';
 $lang['wordblock']             = 'Направените от вас промени не са съхранени, защото съдържат забранен текст (SPAM).';
+$lang['media_uploadtab']       = 'Качване';
+$lang['media_searchtab']       = 'Търсене';
+$lang['media_file']            = 'Файл';
+$lang['media_viewtab']         = 'Преглед';
+$lang['media_edittab']         = 'Редактиране';
+$lang['media_historytab']      = 'История';
+$lang['media_list_thumbs']     = 'Миниатюри';
+$lang['media_list_rows']       = 'Редове';
+$lang['media_sort_name']       = 'Име';
+$lang['media_sort_date']       = 'Дата';
+$lang['media_namespaces']      = 'Изберете:';
+$lang['media_files']           = 'Файлове в %s';
+$lang['media_upload']          = 'Качване в %s';
+$lang['media_search']          = 'Търсене в %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s в %s';
+$lang['media_edit']            = 'Редактиране на %s';
+$lang['media_history']         = 'История на %s';
+$lang['media_meta_edited']     = 'редактиране на метаданните';
+$lang['media_perm_read']       = 'За съжаление нямате достатъчно права, за да можете да прочетете файла.';
+$lang['media_perm_upload']     = 'За съжаление нямате достатъчно права, за да можете да качите файла.';
+$lang['media_update']          = 'Качване на нова версия';
+$lang['media_restore']         = 'Възстановяване на тази версия';
+$lang['plugin_install_err']    = 'Неправилно инсталирана приставка. Моля, преименувайте директорията \'%s\' на \'%s\'.';
