@@ -10,6 +10,7 @@
  * @author Marek Sacha <sachamar@fel.cvut.cz>
  * @author Lefty <lefty@multihost.cz>
  * @author Vojta Beran <xmamut@email.cz>
+ * @author zbynek.krivka@seznam.cz
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -51,6 +52,8 @@ $lang['btn_recover']           = 'Obnovit koncept';
 $lang['btn_draftdel']          = 'Vymazat koncept';
 $lang['btn_revert']            = 'Vrátit zpět';
 $lang['btn_register']          = 'Registrovat';
+$lang['btn_apply']             = 'Použít';
+$lang['btn_media']             = 'Správa médií';
 $lang['loggedinas']            = 'Přihlášen(a) jako';
 $lang['user']                  = 'Uživatelské jméno';
 $lang['pass']                  = 'Heslo';
@@ -95,7 +98,7 @@ $lang['txt_filename']          = 'Wiki jméno (volitelné)';
 $lang['txt_overwrt']           = 'Přepsat existující soubor';
 $lang['lockedby']              = 'Právě zamknuto:';
 $lang['lockexpire']            = 'Zámek vyprší:';
-$lang['willexpire']            = 'Váš zámek pro editaci za chvíli vyprší.\nAbyste předešli konfliktům, stiskněte tlačítko Náhled a zámek se prodlouží.';
+$lang['js']['willexpire']      = 'Váš zámek pro editaci za chvíli vyprší.\nAbyste předešli konfliktům, stiskněte tlačítko Náhled a zámek se prodlouží.';
 $lang['js']['notsavedyet']     = 'Jsou tu neuložené změny, které budou ztraceny.
 Chcete opravdu pokračovat?';
 $lang['js']['searchmedia']     = 'Hledat soubory';
@@ -127,7 +130,17 @@ Přesto tento odkaz můžete zkopírovat a vložit jinde.';
 $lang['js']['linkwiz']         = 'Průvodce odkazy';
 $lang['js']['linkto']          = 'Odkaz na:';
 $lang['js']['del_confirm']     = 'Vymazat tuto položku?';
-$lang['js']['mu_btn']          = 'Načíst více souborů najednou';
+$lang['js']['restore_confirm'] = 'Opravdu obnovit tuto verzi?';
+$lang['js']['media_diff']      = 'Prohlédnout rozdíly:';
+$lang['js']['media_diff_both'] = 'Vedle sebe';
+$lang['js']['media_diff_opacity'] = 'Zvýraznění';
+$lang['js']['media_diff_portions'] = 'Osvědčit';
+$lang['js']['media_select']    = 'Vybrat soubory...';
+$lang['js']['media_upload_btn'] = 'Nahrát';
+$lang['js']['media_done_btn']  = 'Hotovo';
+$lang['js']['media_drop']      = 'Sem přetáhněte soubory pro nahrátí';
+$lang['js']['media_cancel']    = 'odstranit';
+$lang['js']['media_overwrt']   = 'Přepsat existující soubory';
 $lang['rssfailed']             = 'Nastala chyba při vytváření tohoto RSS: ';
 $lang['nothingfound']          = 'Nic nenalezeno.';
 $lang['mediaselect']           = 'Výběr dokumentu';
@@ -162,7 +175,7 @@ $lang['yours']                 = 'Vaše verze';
 $lang['diff']                  = 'Zobrazit rozdíly vůči aktuální verzi';
 $lang['diff2']                 = 'Zobrazit rozdíly mezi vybranými verzemi';
 $lang['difflink']              = 'Odkaz na výstup diff';
-$lang['diff_type']             = 'Prohlédnout rozdíly:';
+$lang['diff_type']             = 'Zobrazit rozdíly:';
 $lang['diff_inline']           = 'Vložené';
 $lang['diff_side']             = 'Přidané';
 $lang['line']                  = 'Řádek';
@@ -182,6 +195,10 @@ $lang['mail_changed']          = 'změna stránky:';
 $lang['mail_subscribe_list']   = 'stránky změněné ve jmenném prostoru:';
 $lang['mail_new_user']         = 'nový uživatel:';
 $lang['mail_upload']           = 'načtený dokument:';
+$lang['changes_type']          = 'Prohlednou změny ';
+$lang['pages_changes']         = 'stránek';
+$lang['media_changes']         = 'souborů médií';
+$lang['both_changes']          = 'stránek i médií';
 $lang['qb_bold']               = 'Tučně';
 $lang['qb_italic']             = 'Kurzíva';
 $lang['qb_underl']             = 'Podtržení';
@@ -222,6 +239,9 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formát';
 $lang['img_camera']            = 'Typ fotoaparátu';
 $lang['img_keywords']          = 'Klíčová slova';
+$lang['img_width']             = 'Šířka';
+$lang['img_height']            = 'Výška';
+$lang['img_manager']           = 'Zobrazit ve správě médií';
 $lang['subscr_subscribe_success'] = '%s byl přihlášen do seznamu odběratelů %s';
 $lang['subscr_subscribe_error'] = 'Došlo k chybě při přihlašování %s do seznamu odběratelů %s';
 $lang['subscr_subscribe_noaddress'] = 'K Vašemu loginu neexistuje žádná adresa, nemohl jste být přihlášen do seznamu odběratelů.';
@@ -236,8 +256,8 @@ $lang['subscr_m_unsubscribe']  = 'Odhlásit z odběru změn emailem';
 $lang['subscr_m_subscribe']    = 'Přihlásit se k odběru změn emailem';
 $lang['subscr_m_receive']      = 'Přejete si dostávat';
 $lang['subscr_style_every']    = 'email pro každou změnu';
-$lang['subscr_style_digest']   = 'souhrnný email změn pro každou stránku';
-$lang['subscr_style_list']     = 'seznam změněných stránek od posledního emailu';
+$lang['subscr_style_digest']   = 'souhrnný email změn pro každou stránku (každé %.2f dny/dní)';
+$lang['subscr_style_list']     = 'seznam změněných stránek od posledního emailu (každé %.2f dny/dní)';
 $lang['authmodfailed']         = 'Autentizace uživatelů je špatně nastavena. Informujte prosím správce této wiki.';
 $lang['authtempfail']          = 'Autentizace uživatelů je dočasně nedostupná. Pokud tento problém přetrvává, informujte prosím správce této wiki.';
 $lang['i_chooselang']          = 'Vyberte si jazyk';
@@ -246,7 +266,7 @@ $lang['i_wikiname']            = 'Název wiki';
 $lang['i_enableacl']           = 'Zapnout ACL (doporučeno)';
 $lang['i_superuser']           = 'Správce';
 $lang['i_problems']            = 'Instalátor narazil na níže popsané problémy. Nelze pokračovat v instalaci, dokud je neopravíte.';
-$lang['i_modified']            = 'Instalátor bude z bezpečnostních důvodů pracovat pouze s čistou a ještě neupravenou instalací DokuWiki. Buď znovu rozbalte souboru z instalačního balíčku nebo se zkuste poradit s <a href="http://dokuwiki.org/install">instrukcemi pro instalaci DokuWiki</a>.';
+$lang['i_modified']            = 'Instalátor bude z bezpečnostních důvodů pracovat pouze s čistou a ještě neupravenou instalací DokuWiki. Buď znovu rozbalte soubory z instalačního balíčku, nebo zkuste prostudovat <a href="http://dokuwiki.org/install">instrukce pro instalaci DokuWiki</a>.';
 $lang['i_funcna']              = 'PHP funkce <code>%s</code> není dostupná. Váš webhosting ji možná z nějakého důvodu vypnul.';
 $lang['i_phpver']              = 'Verze vaší instalace PHP <code>%s</code> je nižší než požadovaná <code>%s</code>. Budete muset aktualizovat svou instalaci PHP.';
 $lang['i_permfail']            = 'DokuWiki nemůže zapisovat do <code>%s</code>. Budete muset opravit práva k tomuto adresáři.';
@@ -262,27 +282,36 @@ $lang['i_pol1']                = 'Veřejná wiki (čtení pro všechny, zápis a
 $lang['i_pol2']                = 'Uzavřená wiki (čtení, zápis a upload pouze pro registrované uživatele)';
 $lang['i_retry']               = 'Zkusit znovu';
 $lang['i_license']             = 'Vyberte prosím licenci obsahu:';
-$lang['mu_intro']              = 'Zde můžete načíst více souborů najednou. Pro přidání souborů do fronty stiskněte tlačítko "Procházet". Až budete hotovi, stiskněte "Načíst".';
-$lang['mu_gridname']           = 'Název souboru';
-$lang['mu_gridsize']           = 'Velikost';
-$lang['mu_gridstat']           = 'Stav';
-$lang['mu_namespace']          = 'Jmenný prostor';
-$lang['mu_browse']             = 'Procházet';
-$lang['mu_toobig']             = 'příliš velké';
-$lang['mu_ready']              = 'připraveno k načtení';
-$lang['mu_done']               = 'hotovo';
-$lang['mu_fail']               = 'selhalo';
-$lang['mu_authfail']           = 'vypršela session';
-$lang['mu_progress']           = '@PCT@% načten';
-$lang['mu_filetypes']          = 'Povolené typy souborů';
-$lang['mu_info']               = 'soubory načteny.';
-$lang['mu_lasterr']            = 'Poslední chyba:';
 $lang['recent_global']         = 'Právě si prohlížíte změny ve jmenném prostoru <b>%s</b>. Také si můžete <a href="%s">zobrazit změny v celé wiki</a>.';
-$lang['years']                 = 'před % roky';
-$lang['months']                = 'před % měsíci';
-$lang['weeks']                 = 'před % týdny';
-$lang['days']                  = 'před % dny';
-$lang['hours']                 = 'před % hodinami';
-$lang['minutes']               = 'před % minutami';
-$lang['seconds']               = 'před % sekundami';
+$lang['years']                 = 'před %d roky';
+$lang['months']                = 'před %d měsíci';
+$lang['weeks']                 = 'před %d týdny';
+$lang['days']                  = 'před %d dny';
+$lang['hours']                 = 'před %d hodinami';
+$lang['minutes']               = 'před %d minutami';
+$lang['seconds']               = 'před %d sekundami';
 $lang['wordblock']             = 'Vaše změny nebyly uloženy, protože obsahují blokovaný text(spam).';
+$lang['media_uploadtab']       = 'Nahrát';
+$lang['media_searchtab']       = 'Hledat';
+$lang['media_file']            = 'Soubor';
+$lang['media_viewtab']         = 'Zobrazit';
+$lang['media_edittab']         = 'Upravit';
+$lang['media_historytab']      = 'Historie';
+$lang['media_list_thumbs']     = 'Zmenšeniny';
+$lang['media_list_rows']       = 'Řádky';
+$lang['media_sort_name']       = 'Jméno';
+$lang['media_sort_date']       = 'Datum';
+$lang['media_namespaces']      = 'Vyber jmenný prostor';
+$lang['media_files']           = 'Soubory v %s';
+$lang['media_upload']          = 'Upload do %s';
+$lang['media_search']          = 'Hledat v %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s na %s';
+$lang['media_edit']            = 'Upravit %s';
+$lang['media_history']         = 'Historie %s';
+$lang['media_meta_edited']     = 'metadata upravena';
+$lang['media_perm_read']       = 'Bohužel, nemáte práva číst soubory.';
+$lang['media_perm_upload']     = 'Bohužel, nemáte práva nahrávat soubory.';
+$lang['media_update']          = 'Nahrát novou verzi';
+$lang['media_restore']         = 'Obnovit tuto verzi';
+$lang['plugin_install_err']    = 'Plugin je špatně nainstalován. Přejmenujte adresář pluginu \'%s\' na \'%s\'.';
