@@ -98,7 +98,7 @@ $lang['txt_filename']          = 'Indtast wikinavn (valgfrit)';
 $lang['txt_overwrt']           = 'Overskriv eksisterende fil';
 $lang['lockedby']              = 'Midlertidig låst af';
 $lang['lockexpire']            = 'Lås udløber kl.';
-$lang['willexpire']            = 'Din lås på dette dokument udløber om et minut.\nTryk på Forhåndsvisning-knappen for at undgå konflikter.';
+$lang['js']['willexpire']            = 'Din lås på dette dokument udløber om et minut.\nTryk på Forhåndsvisning-knappen for at undgå konflikter.';
 $lang['js']['notsavedyet']     = 'Ugemte ændringer vil blive mistet
 Fortsæt alligevel?';
 $lang['js']['searchmedia']     = 'Søg efter filer';
@@ -130,7 +130,6 @@ Du kan stadig kopiere og indsætte linket.';
 $lang['js']['linkwiz']         = 'guiden til henvisninger';
 $lang['js']['linkto']          = 'Henvise til:';
 $lang['js']['del_confirm']     = 'Slet valgte post(er)?';
-$lang['js']['mu_btn']          = 'Overføre flere filer på en gang';
 $lang['rssfailed']             = 'Der opstod en fejl ved indhentning af: ';
 $lang['nothingfound']          = 'Søgningen gav intet resultat.';
 $lang['mediaselect']           = 'Vælg mediefil';
@@ -263,21 +262,6 @@ $lang['i_pol1']                = 'Offentlig Wiki (alle kan læse, kun registrere
 $lang['i_pol2']                = 'Lukket Wiki (kun for registerede brugere kan læse, skrive og overføre)';
 $lang['i_retry']               = 'Forsøg igen';
 $lang['i_license']             = 'Vælg venligst licensen du vil tilføje dit indhold under:';
-$lang['mu_intro']              = 'Her kan du overføre flere filer af gangen. Klik på gennemse for at tilføje dem til køen. Tryk på overføre knappen når du er klar.';
-$lang['mu_gridname']           = 'Filnavn';
-$lang['mu_gridsize']           = 'Størrelse';
-$lang['mu_gridstat']           = 'Status';
-$lang['mu_namespace']          = 'Navnerum';
-$lang['mu_browse']             = 'gennemse';
-$lang['mu_toobig']             = 'for stor';
-$lang['mu_ready']              = 'klar til overføre';
-$lang['mu_done']               = 'færdig';
-$lang['mu_fail']               = 'fejlede';
-$lang['mu_authfail']           = 'session udløb';
-$lang['mu_progress']           = '@PCT@% upload';
-$lang['mu_filetypes']          = 'Tilladte filtyper';
-$lang['mu_info']               = 'filer var overføret.';
-$lang['mu_lasterr']            = 'Sidste fejl:';
 $lang['recent_global']         = 'Du ser lige nu ændringerne i <b>%s</b> navnerummet. Du kan også <a href="%s">se de sidste ændringer for hele wiki siden </a>';
 $lang['years']                 = '%d år siden';
 $lang['months']                = '%d måned siden';
