@@ -7,6 +7,7 @@
  * @author Αθανάσιος Νταής <homunculus@wana.gr>
  * @author Konstantinos Koryllos <koryllos@gmail.com>
  * @author George Petsagourakis <petsagouris@gmail.com>
+ * @author Petros Vidalis <pvidalis@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -48,6 +49,8 @@ $lang['btn_recover']           = 'Επαναφορά αυτόματα αποθη
 $lang['btn_draftdel']          = 'Διαγραφή αυτόματα αποθηκευμένης σελίδας';
 $lang['btn_revert']            = 'Αποκατάσταση';
 $lang['btn_register']          = 'Εγγραφή';
+$lang['btn_apply']             = 'Εφαρμογή';
+$lang['btn_media']             = 'Διαχειριστής πολυμέσων';
 $lang['loggedinas']            = 'Συνδεδεμένος ως';
 $lang['user']                  = 'Όνομα χρήστη';
 $lang['pass']                  = 'Κωδικός';
@@ -92,7 +95,7 @@ $lang['txt_filename']          = 'Επιλέξτε νέο όνομα αρχεί
 $lang['txt_overwrt']           = 'Αντικατάσταση υπάρχοντος αρχείου';
 $lang['lockedby']              = 'Προσωρινά κλειδωμένο από';
 $lang['lockexpire']            = 'Το κλείδωμα λήγει στις';
-$lang['willexpire']            = 'Το κλείδωμά σας για την επεξεργασία αυτής της σελίδας θα λήξει σε ένα λεπτό.\n Για να το ανανεώσετε χρησιμοποιήστε την Προεπισκόπηση.';
+$lang['js']['willexpire']      = 'Το κλείδωμά σας για την επεξεργασία αυτής της σελίδας θα λήξει σε ένα λεπτό.\n Για να το ανανεώσετε χρησιμοποιήστε την Προεπισκόπηση.';
 $lang['js']['notsavedyet']     = 'Οι μη αποθηκευμένες αλλαγές θα χαθούν.
 Θέλετε να συνεχίσετε;';
 $lang['js']['searchmedia']     = 'Αναζήτηση για αρχεία';
@@ -124,7 +127,17 @@ $lang['js']['nosmblinks']      = 'Οι σύνδεσμοι προς Windows share
 $lang['js']['linkwiz']         = 'Αυτόματος Οδηγός Συνδέσμων';
 $lang['js']['linkto']          = 'Σύνδεση σε:';
 $lang['js']['del_confirm']     = 'Να διαγραφεί;';
-$lang['js']['mu_btn']          = 'Ταυτόχρονη φόρτωση πολλαπλών φακέλων';
+$lang['js']['restore_confirm'] = 'Θέλετε την επαναφορά σε αυτή την έκδοση;';
+$lang['js']['media_diff']      = 'Εμφάνιση διαφορών:';
+$lang['js']['media_diff_both'] = 'Δίπλα δίπλα';
+$lang['js']['media_diff_opacity'] = 'Επικάλυψη';
+$lang['js']['media_diff_portions'] = 'Κύλιση';
+$lang['js']['media_select']    = 'Επιλογή αρχείων...';
+$lang['js']['media_upload_btn'] = 'Φόρτωση';
+$lang['js']['media_done_btn']  = 'Ολοκλήρωση';
+$lang['js']['media_drop']      = 'Ρίξτε αρχεία εδώ για να τα φορτώσετε';
+$lang['js']['media_cancel']    = 'αφαίρεση';
+$lang['js']['media_overwrt']   = 'Αντικατάσταση υπάρχοντων αρχείων';
 $lang['rssfailed']             = 'Παρουσιάστηκε κάποιο σφάλμα κατά την ανάγνωση αυτού του feed: ';
 $lang['nothingfound']          = 'Δεν βρέθηκαν σχετικά αποτελέσματα.';
 $lang['mediaselect']           = 'Επιλογή Αρχείων';
@@ -179,6 +192,10 @@ $lang['mail_changed']          = 'σελίδα τροποποιήθηκε:';
 $lang['mail_subscribe_list']   = 'σελίδες που άλλαξαν στον φάκελο:';
 $lang['mail_new_user']         = 'νέος χρήστης:';
 $lang['mail_upload']           = 'αρχείο φορτώθηκε:';
+$lang['changes_type']          = 'Εμφάνιση αλλαγών του';
+$lang['pages_changes']         = 'Σελίδες';
+$lang['media_changes']         = 'Αρχεία πολυμέσων';
+$lang['both_changes']          = 'Σελίδες και αρχεία πολυμέσων';
 $lang['qb_bold']               = 'Έντονο Κείμενο';
 $lang['qb_italic']             = 'Πλάγιο Κείμενο';
 $lang['qb_underl']             = 'Υπογραμμισμένο Κείμενο';
@@ -219,6 +236,9 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Format';
 $lang['img_camera']            = 'Camera';
 $lang['img_keywords']          = 'Λέξεις-κλειδιά';
+$lang['img_width']             = 'Πλάτος';
+$lang['img_height']            = 'Ύψος';
+$lang['img_manager']           = 'Εμφάνιση στον διαχειριστή πολυμέσων';
 $lang['subscr_subscribe_success'] = 'Ο/η %s προστέθηκε στην λίστα ειδοποιήσεων για το %s';
 $lang['subscr_subscribe_error'] = 'Σφάλμα κατά την προσθήκη του/της %s στην λίστα ειδοποιήσεων για το %s';
 $lang['subscr_subscribe_noaddress'] = 'Δεν υπάρχει διεύθυνση ταχυδρομείου συσχετισμένη με το όνομα χρήστη σας. Κατά συνέπεια δεν μπορείτε να προστεθείτε στην λίστα ειδοποιήσεων';
@@ -260,21 +280,6 @@ $lang['i_pol1']                = 'Δημόσιο Wiki (όλοι μπορούν 
 $lang['i_pol2']                = 'Κλειστό Wiki (μόνο οι εγγεγραμμένοι χρήστες μπορούν να διαβάσουν ή να δημιουργήσουν/τροποποιήσουν σελίδες και να μεταφορτώσουν αρχεία)';
 $lang['i_retry']               = 'Νέα προσπάθεια';
 $lang['i_license']             = 'Παρακαλώ επιλέξτε την άδεια που θα χρησιμοποιήσετε για την διάθεση του περιεχομένου σας:';
-$lang['mu_intro']              = 'Εδώ μπορείτε να φορτώσετε ταυτόχρονα πολλαπλά αρχεία. Πατήστε στο κουμπί προεπισκόπησης για να τα προσθέσετε στη λίστα. Πατήστε στο κουμπί μεταφόρτωσης όταν έχετε τελειώσει.';
-$lang['mu_gridname']           = 'Όνομα αρχείου';
-$lang['mu_gridsize']           = 'Μέγεθος';
-$lang['mu_gridstat']           = 'Κατάσταση';
-$lang['mu_namespace']          = 'Φάκελος';
-$lang['mu_browse']             = 'Επισκόπηση';
-$lang['mu_toobig']             = 'υπερβολικά μεγάλο';
-$lang['mu_ready']              = 'έτοιμο για φόρτωση';
-$lang['mu_done']               = 'ολοκληρώθηκε';
-$lang['mu_fail']               = 'απέτυχε';
-$lang['mu_authfail']           = 'η συνεδρία έληξε';
-$lang['mu_progress']           = 'φορτώθηκε @PCT@%';
-$lang['mu_filetypes']          = 'Επιτρεπτοί τύποι αρχείων';
-$lang['mu_info']               = 'τα αρχεία ανέβηκαν.';
-$lang['mu_lasterr']            = 'Τελευταίο σφάλμα:';
 $lang['recent_global']         = 'Βλέπετε τις αλλαγές εντός του φακέλου <b>%s</b>. Μπορείτε επίσης να <a href="%s">δείτε τις πρόσφατες αλλαγές σε όλο το wiki</a>.';
 $lang['years']                 = 'πριν %d χρόνια';
 $lang['months']                = 'πριν %d μήνες';
@@ -283,4 +288,24 @@ $lang['days']                  = 'πριν %d ημέρες';
 $lang['hours']                 = 'πριν %d ώρες';
 $lang['minutes']               = 'πριν %d λεπτά';
 $lang['seconds']               = 'πριν %d δευτερόλεπτα';
-$lang['wordblock']             = 'Η αλλαγή σας δεν αποθηκεύτηκε γιατί περιείχε spam.';
\ No newline at end of file
+$lang['wordblock']             = 'Η αλλαγή σας δεν αποθηκεύτηκε γιατί περιείχε spam.';
+$lang['media_uploadtab']       = 'Φόρτωση';
+$lang['media_searchtab']       = 'Αναζήτηση';
+$lang['media_viewtab']         = 'Εμφάνιση';
+$lang['media_edittab']         = 'Επεξεργασία';
+$lang['media_historytab']      = 'Ιστορικό';
+$lang['media_thumbsview']      = 'Προεπισκόπιση';
+$lang['media_listview']        = 'Λίστα';
+$lang['media_sort']            = 'Ταξινόμιση';
+$lang['media_sort_name']       = 'ανά όνομα';
+$lang['media_sort_date']       = 'ανά ημερομηνία';
+$lang['media_upload']          = 'Φόρτωση στο <strong>%s</strong> φάκελο.';
+$lang['media_search']          = 'Αναζήτηση στο <strong>%s</strong> φάκελο.';
+$lang['media_edit']            = 'Επεξεργασία';
+$lang['media_history']         = 'Αυτές είναι οι παλαιότερες αναθεωρήσεις του αρχείου.';
+$lang['media_meta_edited']     = 'τα μεταδεδομένα επεξεργάστηκαν';
+$lang['media_perm_read']       = 'Συγνώμη, δεν έχετε επαρκή διακαιώματα για να διαβάσετε αυτά τα αρχεία.';
+$lang['media_perm_upload']     = 'Συγνώμη, δεν έχετε επαρκή διακαιώματα για να φορτώσετε αυτά τα αρχεία.';
+$lang['media_update']          = 'Φόρτωση νέας έκδοσης';
+$lang['media_restore']         = 'Επαναφορά αυτή της έκδοσης';
+$lang['plugin_install_err']    = 'Η επέκταση δεν εγκαταστήθηκε σωστά. Μετονομασία φακέλου επεκτάσεων από \'%s\' σε \'%s\'.';
