@@ -7,6 +7,7 @@
  * @author Matti Pöllä <mpo@iki.fi>
  * @author Otto Vainio <otto@valjakko.net>
  * @author Teemu Mattila <ghcsystems@gmail.com>
+ * @author Sami Olmari <sami@olmari.fi>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -48,6 +49,8 @@ $lang['btn_recover']           = 'Palauta luonnos';
 $lang['btn_draftdel']          = 'Poista luonnos';
 $lang['btn_revert']            = 'palauta';
 $lang['btn_register']          = 'Rekisteröidy';
+$lang['btn_apply']             = 'Toteuta';
+$lang['btn_media']             = 'Media manager';
 $lang['loggedinas']            = 'Kirjautunut nimellä';
 $lang['user']                  = 'Käyttäjänimi';
 $lang['pass']                  = 'Salasana';
@@ -92,7 +95,7 @@ $lang['txt_filename']          = 'Lähetä nimellä (valinnainen)';
 $lang['txt_overwrt']           = 'Ylikirjoita olemassa oleva';
 $lang['lockedby']              = 'Tällä hetkellä tiedoston on lukinnut';
 $lang['lockexpire']            = 'Lukitus päättyy';
-$lang['willexpire']            = 'Lukituksesi tämän sivun muokkaukseen päättyy minuutin kuluttua.\nRistiriitojen välttämiseksi paina esikatselu-nappia nollataksesi lukitusajan.';
+$lang['js']['willexpire']      = 'Lukituksesi tämän sivun muokkaukseen päättyy minuutin kuluttua.\nRistiriitojen välttämiseksi paina esikatselu-nappia nollataksesi lukitusajan.';
 $lang['js']['notsavedyet']     = 'Dokumentissa on tallentamattomia muutoksia, jotka häviävät.
  Haluatko varmasti jatkaa?';
 $lang['js']['searchmedia']     = 'Etsi tiedostoja';
@@ -124,7 +127,17 @@ Voit silti kopioida ja liittää linkin.';
 $lang['js']['linkwiz']         = 'Linkkivelho';
 $lang['js']['linkto']          = 'Linkki kohteeseen:';
 $lang['js']['del_confirm']     = 'Haluatko todella poistaa valitut kohteet?';
-$lang['js']['mu_btn']          = 'Lähetä useampia tiedostoja kerralla';
+$lang['js']['restore_confirm'] = 'Haluatko varmasti palauttaa tämän version?';
+$lang['js']['media_diff']      = 'Näytä erot:';
+$lang['js']['media_diff_both'] = 'Vierekkäin';
+$lang['js']['media_diff_opacity'] = 'Päällä';
+$lang['js']['media_diff_portions'] = 'Liukusäädin';
+$lang['js']['media_select']    = 'Valitse tiedostot...';
+$lang['js']['media_upload_btn'] = 'Lähetä';
+$lang['js']['media_done_btn']  = 'Valmis';
+$lang['js']['media_drop']      = 'Pudota lähetettävät tiedostot tähän';
+$lang['js']['media_cancel']    = 'Poista';
+$lang['js']['media_overwrt']   = 'Ylikirjoita olemassa olevat tiedostot';
 $lang['rssfailed']             = 'Virhe tapahtui noudettaessa tätä syötettä: ';
 $lang['nothingfound']          = 'Mitään ei löytynyt.';
 $lang['mediaselect']           = 'Mediatiedoston valinta';
@@ -179,6 +192,10 @@ $lang['mail_changed']          = 'sivu muutettu:';
 $lang['mail_subscribe_list']   = 'muuttuneet sivut nimiavaruudessa:';
 $lang['mail_new_user']         = 'uusi käyttäjä:';
 $lang['mail_upload']           = 'tiedosto lähetetty:';
+$lang['changes_type']          = 'Näytä muutokset:';
+$lang['pages_changes']         = 'Sivut';
+$lang['media_changes']         = 'Mediatiedostot';
+$lang['both_changes']          = 'Sivut ja mediatiedostot';
 $lang['qb_bold']               = 'Lihavoitu teksti';
 $lang['qb_italic']             = 'Kursivoitu teksti';
 $lang['qb_underl']             = 'Alleviivattu teksti';
@@ -219,10 +236,13 @@ $lang['img_copyr']             = 'Tekijänoikeus';
 $lang['img_format']            = 'Formaatti';
 $lang['img_camera']            = 'Kamera';
 $lang['img_keywords']          = 'Avainsanat';
+$lang['img_width']             = 'Leveys';
+$lang['img_height']            = 'Korkeus';
+$lang['img_manager']           = 'Näytä mediamanagerissa';
 $lang['subscr_subscribe_success'] = '%s lisätty %s tilauslistalle';
 $lang['subscr_subscribe_error'] = 'Virhe lisättäessä %s tilauslistalle %s';
 $lang['subscr_subscribe_noaddress'] = 'Login tiedoissasi ei ole sähköpostiosoitetta. Sinua ei voi lisätä tilaukseen';
-$lang['subscr_unsubscribe_success'] = '% poistettu tilauslistalta %s';
+$lang['subscr_unsubscribe_success'] = '%s poistettu tilauslistalta %s';
 $lang['subscr_unsubscribe_error'] = 'Virhe tapahtui poistaessa %s tilauslistalta %s';
 $lang['subscr_already_subscribed'] = '%s on jo tilannut %s';
 $lang['subscr_not_subscribed'] = '%s ei ole tilannut %s';
@@ -233,8 +253,8 @@ $lang['subscr_m_unsubscribe']  = 'Poista tilaus';
 $lang['subscr_m_subscribe']    = 'Tilaa';
 $lang['subscr_m_receive']      = 'Vastaanota';
 $lang['subscr_style_every']    = 'Sähköposti joka muutoksesta';
-$lang['subscr_style_digest']   = 'yhteenveto sähköposti joka sivusta';
-$lang['subscr_style_list']     = 'lista muuttuneista sivuista edellisen sähköpostin jälkeen';
+$lang['subscr_style_digest']   = 'yhteenveto-sähköposti joka sivusta (joka %.2f. päivä)';
+$lang['subscr_style_list']     = 'lista muuttuneista sivuista edellisen sähköpostin jälkeen (joka %.2f. päivä)';
 $lang['authmodfailed']         = 'Käyttäjien autentikoinnin asetukset ovat virheelliset. Ilmoita asiasta wikin ylläpitäjälle.';
 $lang['authtempfail']          = 'Käyttäjien autentikointi ei tällä hetkellä onnistu. Jos ongelma jatkuu, ota yhteyttä wikin ylläpitäjään.';
 $lang['i_chooselang']          = 'Valitse kieli';
@@ -259,21 +279,6 @@ $lang['i_pol1']                = 'Julkinen Wiki (luku kaikilla, kirjoitus ja tie
 $lang['i_pol2']                = 'Suljettu Wiki (luku, kirjoitus ja tiedostojen lähetys vain rekisteröityneillä käyttäjillä)';
 $lang['i_retry']               = 'Yritä uudelleen';
 $lang['i_license']             = 'Valitse lisenssi, jonka alle haluat sisältösi laittaa:';
-$lang['mu_intro']              = 'Täällä voit lähettää useampia tiedostoja kerralla. Klikkaa Selaa-nappia lisätäksesi ne jonoon. Paina lähetä, kun olet valmis.';
-$lang['mu_gridname']           = 'Tiedoston nimi';
-$lang['mu_gridsize']           = 'Koko';
-$lang['mu_gridstat']           = 'Tilanne';
-$lang['mu_namespace']          = 'Nimiavaruus';
-$lang['mu_browse']             = 'Selaa';
-$lang['mu_toobig']             = 'liian iso';
-$lang['mu_ready']              = 'valmis lähetettäväksi';
-$lang['mu_done']               = 'valmis';
-$lang['mu_fail']               = 'epäonnistui';
-$lang['mu_authfail']           = 'istunto on vanhentunut';
-$lang['mu_progress']           = '@PCT@% lähetetty';
-$lang['mu_filetypes']          = 'Sallitut tyypit';
-$lang['mu_info']               = 'tiedostoa ladattu.';
-$lang['mu_lasterr']            = 'Edellinen virhe:';
 $lang['recent_global']         = 'Seuraat tällä hetkellä muutoksia nimiavaruuden <b>%s</b> sisällä. Voit myös <a href="%s">katsoa muutoksia koko wikissä</a>';
 $lang['years']                 = '%d vuotta sitten';
 $lang['months']                = '%d kuukautta sitten';
@@ -281,5 +286,29 @@ $lang['weeks']                 = '%d viikkoa sitten';
 $lang['days']                  = '%d päivää sitten';
 $lang['hours']                 = '%d tuntia sitten';
 $lang['minutes']               = '%d minuuttia sitten';
-$lang['seconds']               = '% sekuntia sitten';
+$lang['seconds']               = '%d sekuntia sitten';
 $lang['wordblock']             = 'Muutostasi ei talletettu, koska se sisältää estettyä tekstiä (spam).';
+$lang['media_uploadtab']       = 'Lähetä';
+$lang['media_searchtab']       = 'Etsi';
+$lang['media_file']            = 'Tiedosto';
+$lang['media_viewtab']         = 'Näytä';
+$lang['media_edittab']         = 'Muokkaa';
+$lang['media_historytab']      = 'Historia';
+$lang['media_list_thumbs']     = 'Thumbnails';
+$lang['media_list_rows']       = 'Rivit';
+$lang['media_sort_name']       = 'nimen mukaan';
+$lang['media_sort_date']       = 'päivämäärän mukaan';
+$lang['media_namespaces']      = 'Valitse nimiavaruus';
+$lang['media_files']           = 'Tiedostoja %s';
+$lang['media_upload']          = 'Lähetä <strong>%s</strong> nimiavaruuteen';
+$lang['media_search']          = 'Etsi <strong>%s</strong> nimiavaruudesta';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s at %s';
+$lang['media_edit']            = 'Muokkaa %s';
+$lang['media_history']         = 'Nämä ovat vanhat versiot tiedostosta %s';
+$lang['media_meta_edited']     = 'Metadataa muokattu';
+$lang['media_perm_read']       = 'Anteeksi. Sinulla ei ole riittävästi oikeuksia lukeaksesi tiedostoja.';
+$lang['media_perm_upload']     = 'Anteeksi. Sinulla ei ole riittävästi oikeuksia lähettääksesi tiedostoja.';
+$lang['media_update']          = 'Lähetä uusi versio';
+$lang['media_restore']         = 'Palauta tämä versio';
+$lang['plugin_install_err']    = 'Liitännäinen asentui virheellisesti. Nimeä liitännäisen hakemisto \'%s\' -> \'%s\'';
