@@ -4,6 +4,7 @@
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Medúlio <medulio@ciberirmandade.org>
+ * @author Oscar M. Lage <r0sk10@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -45,6 +46,8 @@ $lang['btn_recover']           = 'Recuperar borrador';
 $lang['btn_draftdel']          = 'Eliminar borrador';
 $lang['btn_revert']            = 'Restaurar';
 $lang['btn_register']          = 'Rexístrate';
+$lang['btn_apply']             = 'Aplicar';
+$lang['btn_media']             = 'Xestor de Arquivos-Media';
 $lang['loggedinas']            = 'Iniciaches sesión como';
 $lang['user']                  = 'Nome de Usuario';
 $lang['pass']                  = 'Contrasinal';
@@ -89,25 +92,9 @@ $lang['txt_filename']          = 'Subir como (opcional)';
 $lang['txt_overwrt']           = 'Sobrescribir arquivo existente';
 $lang['lockedby']              = 'Bloqueado actualmente por';
 $lang['lockexpire']            = 'O bloqueo remata o';
-$lang['willexpire']            = 'O teu bloqueo para editares esta páxina vai caducar nun minuto.\nPara de evitar conflitos, emprega o botón de previsualización para reiniciares o contador do tempo de bloqueo.';
-$lang['js']['notsavedyet']     = "Perderanse os trocos non gardados.\nEstá certo de quereres continuar?";
-$lang['rssfailed']             = 'Houbo un erro ao tentar obter esta corrente RSS: ';
-$lang['nothingfound']          = 'Non se atopou nada.';
-$lang['mediaselect']           = 'Arquivos-Media';
-$lang['fileupload']            = 'Subida de Arquivos-Media';
-$lang['uploadsucc']            = 'Subida correcta';
-$lang['uploadfail']            = 'Erra na subida. Pode que sexa un problema de permisos?';
-$lang['uploadwrong']           = 'Subida denegada. Esta extensión de arquivo non está permitida!';
-$lang['uploadexist']           = 'Xa existe o arquivo. Non se fixo nada.';
-$lang['uploadbadcontent']      = 'O contido subido non concorda coa extensión do arquivo %s.';
-$lang['uploadspam']            = 'A subida foi bloqueada pola lista negra de correo-lixo.';
-$lang['uploadxss']             = 'A subida foi bloqueada por un posíbel contido malicioso.';
-$lang['uploadsize']            = 'O arquivo subido é grande de máis. (máx. %s)';
-$lang['deletesucc']            = 'O arquivo "%s" foi eliminado.';
-$lang['deletefail']            = '"%s" non puido ser eliminado - comproba os permisos.';
-$lang['mediainuse']            = 'O arquivo "%s" non foi eliminado - aínda está en uso.';
-$lang['namespaces']            = 'Nomes de espazos';
-$lang['mediafiles']            = 'Arquivos dispoñíbeis en';
+$lang['js']['willexpire']      = 'O teu bloqueo para editares esta páxina vai caducar nun minuto.\nPara de evitar conflitos, emprega o botón de previsualización para reiniciares o contador do tempo de bloqueo.';
+$lang['js']['notsavedyet']     = 'Perderanse os trocos non gardados.
+Está certo de quereres continuar?';
 $lang['js']['searchmedia']     = 'Procurar ficheiros';
 $lang['js']['keepopen']        = 'Manter a fiestra aberta na selección';
 $lang['js']['hidedetails']     = 'Agochar Pormenores';
@@ -137,7 +124,35 @@ Sempre podes copiar e colar a ligazón.';
 $lang['js']['linkwiz']         = 'Asistente de ligazóns';
 $lang['js']['linkto']          = 'Ligazón para:';
 $lang['js']['del_confirm']     = 'Estás certo de quereres eliminar os elementos seleccionados?';
-$lang['js']['mu_btn']          = 'Subir varios arquivos de vez';
+$lang['js']['restore_confirm'] = 'Realmente desexas restaurar esta versión?';
+$lang['js']['media_diff']      = 'Ver as diferencias:';
+$lang['js']['media_diff_both'] = 'Cara a Cara';
+$lang['js']['media_diff_opacity'] = 'Opacidade';
+$lang['js']['media_diff_portions'] = 'Porcións';
+$lang['js']['media_select']    = 'Selecciona arquivos...';
+$lang['js']['media_upload_btn'] = 'Subir';
+$lang['js']['media_done_btn']  = 'Feito';
+$lang['js']['media_drop']      = 'Solta aquí os arquivos a subir';
+$lang['js']['media_cancel']    = 'eliminar';
+$lang['js']['media_overwrt']   = 'Sobreescribir os arquivos existentes';
+$lang['rssfailed']             = 'Houbo un erro ao tentar obter esta corrente RSS: ';
+$lang['nothingfound']          = 'Non se atopou nada.';
+$lang['mediaselect']           = 'Arquivos-Media';
+$lang['fileupload']            = 'Subida de Arquivos-Media';
+$lang['uploadsucc']            = 'Subida correcta';
+$lang['uploadfail']            = 'Erra na subida. Pode que sexa un problema de permisos?';
+$lang['uploadwrong']           = 'Subida denegada. Esta extensión de arquivo non está permitida!';
+$lang['uploadexist']           = 'Xa existe o arquivo. Non se fixo nada.';
+$lang['uploadbadcontent']      = 'O contido subido non concorda coa extensión do arquivo %s.';
+$lang['uploadspam']            = 'A subida foi bloqueada pola lista negra de correo-lixo.';
+$lang['uploadxss']             = 'A subida foi bloqueada por un posíbel contido malicioso.';
+$lang['uploadsize']            = 'O arquivo subido é grande de máis. (máx. %s)';
+$lang['deletesucc']            = 'O arquivo "%s" foi eliminado.';
+$lang['deletefail']            = '"%s" non puido ser eliminado - comproba os permisos.';
+$lang['mediainuse']            = 'O arquivo "%s" non foi eliminado - aínda está en uso.';
+$lang['namespaces']            = 'Nomes de espazos';
+$lang['mediafiles']            = 'Arquivos dispoñíbeis en';
+$lang['accessdenied']          = 'Non tes permitido ver esta páxina.';
 $lang['mediausage']            = 'Emprega a seguinte sintaxe para inserires unha referencia a este arquivo:';
 $lang['mediaview']             = 'Ver arquivo orixinal';
 $lang['mediaroot']             = 'raigaña';
@@ -153,6 +168,10 @@ $lang['current']               = 'actual';
 $lang['yours']                 = 'A túa Versión';
 $lang['diff']                  = 'Amosar diferenzas coa versión actual';
 $lang['diff2']                 = 'Amosar diferenzas entre as revisións seleccionadas';
+$lang['difflink']              = 'Enlazar a esta vista de comparación';
+$lang['diff_type']             = 'Ver diferenzas:';
+$lang['diff_inline']           = 'Por liña';
+$lang['diff_side']             = 'Cara a Cara';
 $lang['line']                  = 'Liña';
 $lang['breadcrumb']            = 'Trazado';
 $lang['youarehere']            = 'Estás aquí';
@@ -170,6 +189,10 @@ $lang['mail_changed']          = 'páxina mudada:';
 $lang['mail_subscribe_list']   = 'páxinas mudadas en nome de espazo:';
 $lang['mail_new_user']         = 'Novo usuario:';
 $lang['mail_upload']           = 'arquivo subido:';
+$lang['changes_type']          = 'Ver cambios';
+$lang['pages_changes']         = 'Páxinas';
+$lang['media_changes']         = 'Arquivos-Media';
+$lang['both_changes']          = 'Ambos, páxinas e arquivos-media';
 $lang['qb_bold']               = 'Texto Resaltado';
 $lang['qb_italic']             = 'Texto en Cursiva';
 $lang['qb_underl']             = 'Texto Subliñado';
@@ -210,6 +233,9 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formato';
 $lang['img_camera']            = 'Cámara';
 $lang['img_keywords']          = 'Verbas chave';
+$lang['img_width']             = 'Ancho';
+$lang['img_height']            = 'Alto';
+$lang['img_manager']           = 'Ver no xestor de arquivos-media';
 $lang['subscr_subscribe_success'] = 'Engadido %s á lista de subscrición para %s';
 $lang['subscr_subscribe_error'] = 'Erro ao tentar engadir %s á lista de subscrición para %s';
 $lang['subscr_subscribe_noaddress'] = 'Non hai enderezos asociados co teu inicio de sesión, non é posíbel engadirte á lista de subscrición';
@@ -253,21 +279,7 @@ $lang['i_pol0']                = 'Wiki Aberto (lectura, escritura, subida de arq
 $lang['i_pol1']                = 'Wiki Público (lectura para todas as persoas, escritura e subida de arquivos para usuarios rexistrados)';
 $lang['i_pol2']                = 'Wiki Fechado (lectura, escritura, subida de arquivos só para usuarios rexistrados)';
 $lang['i_retry']               = 'Tentar de novo';
-$lang['mu_intro']              = 'Aquí podes subir varios arquivos de vez. Preme o botón Navegar para engadilos á cola. Preme en Subir cando remates.';
-$lang['mu_gridname']           = 'Nome de Arquivo';
-$lang['mu_gridsize']           = 'Tamaño';
-$lang['mu_gridstat']           = 'Estado';
-$lang['mu_namespace']          = 'Nome de Espazo';
-$lang['mu_browse']             = 'Navegar';
-$lang['mu_toobig']             = 'grande de máis';
-$lang['mu_ready']              = 'disposto para subir';
-$lang['mu_done']               = 'feito';
-$lang['mu_fail']               = 'fallou';
-$lang['mu_authfail']           = 'sesión expirada';
-$lang['mu_progress']           = '@PCT@% subido';
-$lang['mu_filetypes']          = 'Tipos de arquivo Permitidos';
-$lang['mu_info']               = 'arquivos subidos.';
-$lang['mu_lasterr']            = 'Último erro:';
+$lang['i_license']             = 'Por favor escolla a licenza para o contido:';
 $lang['recent_global']         = 'Agora mesmo estás a ver os trocos no nome de espazo <b>%s</b>. Tamén podes <a href="%s">ver os trocos recentes no Wiki enteiro</a>.';
 $lang['years']                 = 'hai %d anos';
 $lang['months']                = 'hai %d meses';
@@ -276,3 +288,28 @@ $lang['days']                  = 'hai %d días';
 $lang['hours']                 = 'hai %d horas';
 $lang['minutes']               = 'hai %d minutos';
 $lang['seconds']               = 'hai %d segundos';
+$lang['wordblock']             = 'Non se gardaron os cambios porque conteñen texto bloqueado (spam).';
+$lang['media_uploadtab']       = 'Subir';
+$lang['media_searchtab']       = 'Buscar';
+$lang['media_file']            = 'Arquivo';
+$lang['media_viewtab']         = 'Ver';
+$lang['media_edittab']         = 'Editar';
+$lang['media_historytab']      = 'Histórico';
+$lang['media_list_thumbs']     = 'Miniaturas';
+$lang['media_list_rows']       = 'Filas';
+$lang['media_sort_name']       = 'Nome';
+$lang['media_sort_date']       = 'Data';
+$lang['media_namespaces']      = 'Escolla espazo';
+$lang['media_files']           = 'Arquivos en %s';
+$lang['media_upload']          = 'Subir a %s';
+$lang['media_search']          = 'Buscar en %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s en %s';
+$lang['media_edit']            = 'Editar %s';
+$lang['media_history']         = 'Historia de %s';
+$lang['media_meta_edited']     = 'datos meta editados';
+$lang['media_perm_read']       = 'Sentímolo, non tes permisos suficientes para ler arquivos.';
+$lang['media_perm_upload']     = 'Sentímolo, non tes permisos suficientes para subir arquivos.';
+$lang['media_update']          = 'Subir nova versión';
+$lang['media_restore']         = 'Restaurar esta versión';
+$lang['plugin_install_err']    = 'Extensión instalada correctamente. Re-nomea o directorio da extensión de \'%s\' a \'%s\'.';
