@@ -29,7 +29,7 @@ $lang['btn_revs']              = '以前のリビジョン';
 $lang['btn_recent']            = '最近の変更';
 $lang['btn_upload']            = 'アップロード';
 $lang['btn_cancel']            = 'キャンセル';
-$lang['btn_index']             = '索引';
+$lang['btn_index']             = 'サイトマップ';
 $lang['btn_secedit']           = '編集';
 $lang['btn_login']             = 'ログイン';
 $lang['btn_logout']            = 'ログアウト';
@@ -48,6 +48,8 @@ $lang['btn_recover']           = 'ドラフトを復元';
 $lang['btn_draftdel']          = 'ドラフトを削除';
 $lang['btn_revert']            = '元に戻す';
 $lang['btn_register']          = 'ユーザー登録';
+$lang['btn_apply']             = '適用';
+$lang['btn_media']             = 'メディアマネージャー';
 $lang['loggedinas']            = 'ようこそ';
 $lang['user']                  = 'ユーザー名';
 $lang['pass']                  = 'パスワード';
@@ -92,7 +94,7 @@ $lang['txt_filename']          = '名前を変更してアップロード（オ
 $lang['txt_overwrt']           = '既存のファイルを上書き';
 $lang['lockedby']              = 'この文書は次のユーザによってロックされています';
 $lang['lockexpire']            = 'ロック期限：';
-$lang['willexpire']            = '編集中の文書はロック期限を過ぎようとしています。このままロックする場合は、一度文書の確認を行って期限をリセットしてください。';
+$lang['js']['willexpire']      = '編集中の文書はロック期限を過ぎようとしています。このままロックする場合は、一度文書の確認を行って期限をリセットしてください。';
 $lang['js']['notsavedyet']     = '変更は保存されません。このまま処理を続けてよろしいですか？';
 $lang['js']['searchmedia']     = 'ファイル検索';
 $lang['js']['keepopen']        = '選択中はウィンドウを閉じない';
@@ -123,10 +125,20 @@ $lang['js']['nosmblinks']      = 'ウィンドウズの共有フォルダへリ
 $lang['js']['linkwiz']         = 'リンクウィザード';
 $lang['js']['linkto']          = 'リンク先：';
 $lang['js']['del_confirm']     = '選択した項目を本当に削除しますか？';
-$lang['js']['mu_btn']          = '複数のファイルを一度にアップロード';
+$lang['js']['restore_confirm'] = '本当にこのバージョンを復元しますか?';
+$lang['js']['media_diff']      = '差分の表示方法:';
+$lang['js']['media_diff_both'] = '並べて表示';
+$lang['js']['media_diff_opacity'] = '重ねて透過表示';
+$lang['js']['media_diff_portions'] = '重ねて切替表示';
+$lang['js']['media_select']    = 'ファイルを選択...';
+$lang['js']['media_upload_btn'] = 'アップロード';
+$lang['js']['media_done_btn']  = '完了';
+$lang['js']['media_drop']      = 'ここにファイルをドロップするとアップロードします';
+$lang['js']['media_cancel']    = '削除';
+$lang['js']['media_overwrt']   = '既存のファイルを上書きする';
 $lang['rssfailed']             = 'RSSの取得に失敗しました：';
 $lang['nothingfound']          = '該当文書はありませんでした。';
-$lang['mediaselect']           = 'メディアファイルを選択';
+$lang['mediaselect']           = 'メディアファイル';
 $lang['fileupload']            = 'メディアファイルをアップロード';
 $lang['uploadsucc']            = 'アップロード完了';
 $lang['uploadfail']            = 'アップロードに失敗しました。権限がありません。';
@@ -178,6 +190,10 @@ $lang['mail_changed']          = '文書の変更：';
 $lang['mail_subscribe_list']   = '名前空間内でページが変更：';
 $lang['mail_new_user']         = '新規ユーザー：';
 $lang['mail_upload']           = 'ファイルのアップロード：';
+$lang['changes_type']          = '表示する変更のタイプ:';
+$lang['pages_changes']         = 'ページの変更';
+$lang['media_changes']         = 'メディアファイルの変更';
+$lang['both_changes']          = 'ページとメディアファイルの変更';
 $lang['qb_bold']               = '太字';
 $lang['qb_italic']             = '斜体';
 $lang['qb_underl']             = '下線';
@@ -218,6 +234,9 @@ $lang['img_copyr']             = '著作権';
 $lang['img_format']            = 'フォーマット';
 $lang['img_camera']            = '使用カメラ';
 $lang['img_keywords']          = 'キーワード';
+$lang['img_width']             = '幅';
+$lang['img_height']            = '高さ';
+$lang['img_manager']           = 'メディアマネージャーで閲覧';
 $lang['subscr_subscribe_success'] = '%sが%sの購読リストに登録されました。';
 $lang['subscr_subscribe_error'] = '%sを%sの購読リストへの追加に失敗しました。';
 $lang['subscr_subscribe_noaddress'] = 'あなたのログインに対応するアドレスがないため、購読リストへ追加することができません。';
@@ -260,21 +279,6 @@ $lang['i_pol1']                = 'パブリック Wiki（閲覧は全ての人
 $lang['i_pol2']                = 'クローズド Wiki (登録ユーザーにのみ使用を許可)';
 $lang['i_retry']               = '再試行';
 $lang['i_license']             = 'あなたが作成したコンテンツが属するライセンスを選択してください：';
-$lang['mu_intro']              = '複数のファイルを一度にアップロードできます。ブラウズボタンをクリックしてファイルを追加してください。追加したら、アップロードボタンをクリックしてください。';
-$lang['mu_gridname']           = 'ファイル名';
-$lang['mu_gridsize']           = 'サイズ';
-$lang['mu_gridstat']           = 'ステータス';
-$lang['mu_namespace']          = '名前空間';
-$lang['mu_browse']             = 'ブラウズ';
-$lang['mu_toobig']             = '大きすぎます';
-$lang['mu_ready']              = 'アップロードできます';
-$lang['mu_done']               = '完了';
-$lang['mu_fail']               = '失敗';
-$lang['mu_authfail']           = 'セッション期限切れ';
-$lang['mu_progress']           = '@PCT@% アップロード完了';
-$lang['mu_filetypes']          = '使用できるファイル形式';
-$lang['mu_info']               = 'ファイルアップロード完了';
-$lang['mu_lasterr']            = '直近のエラー：';
 $lang['recent_global']         = '現在、<b>%s</b> 名前空間内の変更点を閲覧中です。<a href="%s">Wiki全体の最近の変更点を確認する</a>ことも可能です。';
 $lang['years']                 = '%d年前';
 $lang['months']                = '%dカ月前';
@@ -284,3 +288,27 @@ $lang['hours']                 = '%d時間前';
 $lang['minutes']               = '%d分前';
 $lang['seconds']               = '%d秒前';
 $lang['wordblock']             = 'スパムと認識されるテキストが含まれているため、変更は保存されませんでした。';
+$lang['media_uploadtab']       = 'アップロード';
+$lang['media_searchtab']       = '検索';
+$lang['media_file']            = 'ファイル';
+$lang['media_viewtab']         = '詳細';
+$lang['media_edittab']         = '編集';
+$lang['media_historytab']      = '履歴';
+$lang['media_list_thumbs']     = 'サムネイル';
+$lang['media_list_rows']       = '行';
+$lang['media_sort_name']       = '名前';
+$lang['media_sort_date']       = '日付';
+$lang['media_namespaces']      = '名前空間を選択';
+$lang['media_files']           = '%s 内のファイル';
+$lang['media_upload']          = '%s にアップロード';
+$lang['media_search']          = '%s 内で検索';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s at %s';
+$lang['media_edit']            = '%s を編集';
+$lang['media_history']         = '%s の履歴';
+$lang['media_meta_edited']     = 'メタデータが編集されました';
+$lang['media_perm_read']       = 'ファイルを閲覧する権限がありません。';
+$lang['media_perm_upload']     = 'ファイルをアップロードする権限がありません。';
+$lang['media_update']          = '新しいバージョンをアップロード';
+$lang['media_restore']         = 'このバージョンを復元';
+$lang['plugin_install_err']    = 'プラグインが正しくインストールされませんでした。プラグインのディレクトリ名を \'%s\' から \'%s\' に変更してください。';
