@@ -92,7 +92,7 @@ $lang['txt_filename']          = 'Качи како (неморално)';
 $lang['txt_overwrt']           = 'Пребриши ја веќе постоечката датотека';
 $lang['lockedby']              = 'Моментално заклучена од';
 $lang['lockexpire']            = 'Клучот истекува на';
-$lang['willexpire']            = 'Вашиот клуч за уредување на оваа страница ќе истече за една минута.\nЗа да избегнете конфликти и да го ресетирате бројачот за време, искористете го копчето за преглед.';
+$lang['js']['willexpire']            = 'Вашиот клуч за уредување на оваа страница ќе истече за една минута.\nЗа да избегнете конфликти и да го ресетирате бројачот за време, искористете го копчето за преглед.';
 $lang['js']['notsavedyet']     = "Незачуваните промени ќе бидат изгубени.\nСакате да продолжите?";
 $lang['rssfailed']             = 'Се појави грешка при повлекувањето на овој канал:';
 $lang['nothingfound']          = 'Ништо не е пронајдено.';
@@ -117,7 +117,6 @@ $lang['js']['nosmblinks']      = 'Поврзувањето со Windows Shares 
 $lang['js']['linkwiz']         = 'Волшебник за врски';
 $lang['js']['linkto']          = 'Врска до:';
 $lang['js']['del_confirm']     = 'Дали навистина да ги избришам избраните датотеки?';
-$lang['js']['mu_btn']          = 'Качете повеќе датотеки наеднаш';
 $lang['mediausage']            = 'Користете ја следнава синтакса за референцирање кон оваа датотека:';
 $lang['mediaview']             = 'Види ја оригиналната датотека';
 $lang['mediaroot']             = 'root';
@@ -224,20 +223,6 @@ $lang['i_pol0']                = 'Отвори вики (читај, запиш
 $lang['i_pol1']                = 'Јавно вики (читај за сите, запиши и качи за регистрирани корисници)';
 $lang['i_pol2']                = 'Затворено вики (читај, запиши, качи само за регистрирани корисници)';
 $lang['i_retry']               = 'Пробај повторно';
-$lang['mu_intro']              = 'Овде можете да прикачите повеќе датотеки од еднаш. Кликнете на копчето за пребарување за да ги додадете во редица. Притиснете на качи кога е готово.';
-$lang['mu_gridname']           = 'Име на датотека';
-$lang['mu_gridsize']           = 'Големина';
-$lang['mu_gridstat']           = 'Состојба';
-$lang['mu_browse']             = 'Пребарај';
-$lang['mu_toobig']             = 'премногу голема';
-$lang['mu_ready']              = 'спремна за качување';
-$lang['mu_done']               = 'комплетно';
-$lang['mu_fail']               = 'неуспешно';
-$lang['mu_authfail']           = 'сесијата истече';
-$lang['mu_progress']           = '@PCT@% качено';
-$lang['mu_filetypes']          = 'Дозволено типови на датотеки';
-$lang['mu_info']               = 'качени датотеки.';
-$lang['mu_lasterr']            = 'Последна грешка: ';
 $lang['years']                 = 'пред %d години';
 $lang['months']                = 'пред %d месеци';
 $lang['weeks']                 = 'пред %d недели';
