@@ -7,6 +7,8 @@
  * @author Sergiu Baltariu <s_baltariu@yahoo.com>
  * @author Emanuel-Emeric Andrași <n30@mandrivausers.ro>
  * @author Emanuel-Emeric Andraşi <em.andrasi@mandrivausers.ro>
+ * @author Marius OLAR <olarmariusalex@gmail.com>
+ * @author Emanuel-Emeric Andrași <em.andrasi@mandrivausers.ro>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -48,6 +50,8 @@ $lang['btn_recover']           = 'Recuperează schiţă';
 $lang['btn_draftdel']          = 'Şterge schiţă';
 $lang['btn_revert']            = 'Revenire';
 $lang['btn_register']          = 'Înregistrează';
+$lang['btn_apply']             = 'Aplică';
+$lang['btn_media']             = 'Administrare media';
 $lang['loggedinas']            = 'Logat ca şi';
 $lang['user']                  = 'Utilizator';
 $lang['pass']                  = 'Parola';
@@ -92,7 +96,7 @@ $lang['txt_filename']          = 'Încarcă fişierul ca (opţional)';
 $lang['txt_overwrt']           = 'Suprascrie fişierul existent';
 $lang['lockedby']              = 'Momentan blocat de';
 $lang['lockexpire']            = 'Blocarea expiră la';
-$lang['willexpire']            = 'Blocarea pentru editarea paginii expiră intr-un minut.\nPentru a preveni conflictele foloseşte butonul de previzualizare pentru resetarea blocării.';
+$lang['js']['willexpire']      = 'Blocarea pentru editarea paginii expiră intr-un minut.\nPentru a preveni conflictele foloseşte butonul de previzualizare pentru resetarea blocării.';
 $lang['js']['notsavedyet']     = 'Există modificări nesalvate, care se vor pierde.
 Doreşti să continui?';
 $lang['js']['searchmedia']     = 'Caută fişiere';
@@ -124,7 +128,17 @@ Puteţi însă copia şi insera legătura.';
 $lang['js']['linkwiz']         = 'Asistent legătură';
 $lang['js']['linkto']          = 'Legătură la:';
 $lang['js']['del_confirm']     = 'Doriţi într-adevăr ştergerea elementelor selectate?';
-$lang['js']['mu_btn']          = 'Încarcă mai multe fişiere simultan';
+$lang['js']['restore_confirm'] = 'Sunteți sigur că doriți restaurarea acestei versiuni?';
+$lang['js']['media_diff']      = 'Arată diferențele:';
+$lang['js']['media_diff_both'] = 'Unul lângă altul';
+$lang['js']['media_diff_opacity'] = 'Străveziu';
+$lang['js']['media_diff_portions'] = 'Lovește cu putere';
+$lang['js']['media_select']    = 'Selectează fișierele...';
+$lang['js']['media_upload_btn'] = 'Încarcă';
+$lang['js']['media_done_btn']  = 'Gata';
+$lang['js']['media_drop']      = 'Lasă fișierele aici pentru încărcarea lor';
+$lang['js']['media_cancel']    = 'înlătură';
+$lang['js']['media_overwrt']   = 'Suprascrie fișierele deja existente';
 $lang['rssfailed']             = 'A apărut o eroare in timpul descărcării acestui cîmp: ';
 $lang['nothingfound']          = 'Nu am găsit nimic.';
 $lang['mediaselect']           = 'Selectare fişiere media';
@@ -179,6 +193,10 @@ $lang['mail_changed']          = 'page schimbată:';
 $lang['mail_subscribe_list']   = 'pagini modificate în spaţiul de nume:';
 $lang['mail_new_user']         = 'utilizator nou';
 $lang['mail_upload']           = 'fişier încărcat:';
+$lang['changes_type']          = 'Vizualizare modificări';
+$lang['pages_changes']         = 'Pagini';
+$lang['media_changes']         = 'Fișiere media';
+$lang['both_changes']          = 'Ambele pagini şi fişiere media';
 $lang['qb_bold']               = 'Text Îngroşat';
 $lang['qb_italic']             = 'Text Italic';
 $lang['qb_underl']             = 'Text Subliniat';
@@ -219,6 +237,9 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Format';
 $lang['img_camera']            = 'Camera';
 $lang['img_keywords']          = 'Cuvinte cheie';
+$lang['img_width']             = 'Lățime';
+$lang['img_height']            = 'Înălțime';
+$lang['img_manager']           = 'Vizualizează în administratorul media';
 $lang['subscr_subscribe_success'] = 'Adăugat %s la lista de abonare pentru %s';
 $lang['subscr_subscribe_error'] = 'Eroare la adăugarea %s la lista de abonare pentru %s';
 $lang['subscr_subscribe_noaddress'] = 'Nu există adresa asociată cu logarea dvs., nu puteţi fi adăugat la lista de abonare';
@@ -260,21 +281,6 @@ $lang['i_pol1']                = 'Wiki Deschisă (citeste oricine, scrie şi în
 $lang['i_pol2']                = 'Wiki Închisă (citeşte, scrie şi încarcă doar utilizatorul înregistrat)';
 $lang['i_retry']               = 'Încearcă din nou';
 $lang['i_license']             = 'Vă rugăm alegeţi licenţa sub care doriţi să vă licenţiaţi materialul:';
-$lang['mu_intro']              = 'Aici poţi încărca mai multe fişiere simultan. Apasă butonul Răsfoieşte pentru a le adăuga. Apasă Încarcă când ai terminat.';
-$lang['mu_gridname']           = 'Numele fişierului';
-$lang['mu_gridsize']           = 'Mărime';
-$lang['mu_gridstat']           = 'Stare';
-$lang['mu_namespace']          = 'Spaţiu de nume';
-$lang['mu_browse']             = 'Răsfoieşte';
-$lang['mu_toobig']             = 'prea mare';
-$lang['mu_ready']              = 'pregătit pentru încărcare';
-$lang['mu_done']               = 'complet';
-$lang['mu_fail']               = 'eşuat';
-$lang['mu_authfail']           = 'sesiunea a expirat';
-$lang['mu_progress']           = '@PCT@% incărcat';
-$lang['mu_filetypes']          = 'Tipuri de fişiere permise';
-$lang['mu_info']               = 'fişiere încărcate';
-$lang['mu_lasterr']            = 'Ultima eroare:';
 $lang['recent_global']         = 'Acum vizualizaţi modificările în interiorul numelui de spaţiu <b>%s</b>. De asemenea puteţi <a href="%s">vizualiza modificările recente ale întregului wiki</a>.';
 $lang['years']                 = 'acum %d ani';
 $lang['months']                = 'acum %d luni';
@@ -284,3 +290,27 @@ $lang['hours']                 = 'acum %d ore';
 $lang['minutes']               = 'acum %d minute';
 $lang['seconds']               = 'acum %d secunde';
 $lang['wordblock']             = 'Modificarea dvs. nu au fost salvate deoarece conţine text blocat (spam).';
+$lang['media_uploadtab']       = 'Încarcă';
+$lang['media_searchtab']       = 'Căutare';
+$lang['media_file']            = 'Fișier';
+$lang['media_viewtab']         = 'Vizualizare';
+$lang['media_edittab']         = 'Editare';
+$lang['media_historytab']      = 'Istoric';
+$lang['media_list_thumbs']     = 'Miniaturi';
+$lang['media_list_rows']       = 'Linii';
+$lang['media_sort_name']       = 'Nume';
+$lang['media_sort_date']       = 'Data';
+$lang['media_namespaces']      = 'Alegeți numele se spațiu';
+$lang['media_files']           = 'Fișiere în %s';
+$lang['media_upload']          = 'Încarcă în %s';
+$lang['media_search']          = 'Caută în %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s în %s';
+$lang['media_edit']            = 'Editare %s';
+$lang['media_history']         = 'Istoricul pentru %s';
+$lang['media_meta_edited']     = 'metadate editate';
+$lang['media_perm_read']       = 'Ne pare rău, dar nu aveți suficiente drepturi pentru a putea citi fișiere.';
+$lang['media_perm_upload']     = 'Ne pare rău, dar nu aveți suficiente drepturi pentru a putea încărca fișiere.';
+$lang['media_update']          = 'Încarcă noua versiune';
+$lang['media_restore']         = 'Restaurează această versiune';
+$lang['plugin_install_err']    = 'Modul instalat greșit. Redenumește directorul modulului \'%s\' în \'%s\'.';
