@@ -93,7 +93,7 @@ $lang['txt_filename']          = 'Pošlji z imenom (izborno)';
 $lang['txt_overwrt']           = 'Prepiši obstoječo datoteko';
 $lang['lockedby']              = 'Trenutno je zaklenjeno s strani';
 $lang['lockexpire']            = 'Zaklep preteče ob';
-$lang['willexpire']            = 'Zaklep za urejevanje bo pretekel čez eno minuto.\nV izogib sporom, uporabite predogled, da se merilnik časa za zaklep ponastavi.';
+$lang['js']['willexpire']            = 'Zaklep za urejevanje bo pretekel čez eno minuto.\nV izogib sporom, uporabite predogled, da se merilnik časa za zaklep ponastavi.';
 $lang['js']['notsavedyet']     = 'Neshranjene spremembe bodo izgubljene.';
 $lang['js']['searchmedia']     = 'Poišči datoteke';
 $lang['js']['keepopen']        = 'Od izbiri ohrani okno odprto';
@@ -123,7 +123,6 @@ $lang['js']['nosmblinks']      = 'Povezovanje do souporabnih datotek sistema Win
 $lang['js']['linkwiz']         = 'Čarovnik za povezave';
 $lang['js']['linkto']          = 'Poveži na:';
 $lang['js']['del_confirm']     = 'Ali naj se res izbrišejo izbrani predmeti?';
-$lang['js']['mu_btn']          = 'Pošiljanje več dokumentov hkrati.';
 $lang['rssfailed']             = 'Prišlo je do napake med pridobivanjem vira: ';
 $lang['nothingfound']          = 'Ni najdenih predmetov.';
 $lang['mediaselect']           = 'Predstavne datoteke';
@@ -255,21 +254,6 @@ $lang['i_pol1']                = 'Javni Wiki (branje za vse, zapis in nalaganje
 $lang['i_pol2']                = 'Zaprt Wiki (berejo in urejajo lahko le prijavljeni uporabniki)';
 $lang['i_retry']               = 'Ponovni poskus';
 $lang['i_license']             = 'Izbor dovoljenja objave vsebine:';
-$lang['mu_intro']              = 'Naložiti je mogoče več datotek hkrati. S klikom na gumb "Prebrskaj", jih je mogoče dodati v vrsto. S klikom na povezavo "naloži" bodo datoteke poslane na strežnik.';
-$lang['mu_gridname']           = 'Ime datoteke';
-$lang['mu_gridsize']           = 'Velikost';
-$lang['mu_gridstat']           = 'Stanje';
-$lang['mu_namespace']          = 'Imenski prostor';
-$lang['mu_browse']             = 'Prebrskaj';
-$lang['mu_toobig']             = 'prevelika datoteka';
-$lang['mu_ready']              = 'pripravljena na pošiljanje';
-$lang['mu_done']               = 'končano';
-$lang['mu_fail']               = 'ni uspelo';
-$lang['mu_authfail']           = 'seja je potekla';
-$lang['mu_progress']           = '@PCT@% je poslano';
-$lang['mu_filetypes']          = 'Dovoljene vrste datotek';
-$lang['mu_info']               = 'poslanih datotek.';
-$lang['mu_lasterr']            = 'Zadnja napaka:';
 $lang['recent_global']         = 'Trenutno so prikazane spremembe znotraj imenskega prostora <b>%s</b>. Mogoče si je ogledati tudi spremembe <a href="%s">celotnega sistema Wiki</a>.';
 $lang['years']                 = '%d let nazaj';
 $lang['months']                = '%d mesecev nazaj';
