@@ -46,8 +46,6 @@ $lang['btn_backlink']          = 'หน้าที่ลิงก์มา';
 $lang['btn_backtomedia']       = 'กลับไปยังหน้าเลือกไฟล์สื่อ';
 $lang['btn_subscribe']         = 'เฝ้าดู';
 $lang['btn_unsubscribe']       = 'เลิกเฝ้าดู';
-$lang['btn_subscribens']       = 'สมัครเพื่อตามการเปลี่ยนแปลงเนมสเปซ';
-$lang['btn_unsubscribens']     = 'ยกเลิกสมัครเพื่อตามการเปลี่ยนแปลงเนมสเปซ';
 $lang['btn_profile']           = 'แก้ข้อมูลผู้ใช้';
 $lang['btn_reset']             = 'เริ่มใหม่';
 $lang['btn_resendpwd']         = 'ลืมรหัส ส่งให้ใหม่ทางอีเมล';
@@ -100,7 +98,7 @@ $lang['txt_filename']          = 'อัพโหลดเป็น(ตัวเ
 $lang['txt_overwrt']           = 'เขียนทับไฟล์ที่มีอยู่แล้ว';
 $lang['lockedby']              = 'ตอนนี้ถูกล๊อคโดย';
 $lang['lockexpire']            = 'การล๊อคจะหมดอายุเมื่อ';
-$lang['willexpire']            = 'การล๊อคเพื่อแก้ไขหน้านี้กำลังจะหมดเวลาในอีก \n นาที เพื่อที่จะหลีกเลี่ยงข้อขัดแย้งให้ใช้ปุ่ม "Preview" เพื่อรีเซ็ทเวลาใหม่';
+$lang['js']['willexpire']            = 'การล๊อคเพื่อแก้ไขหน้านี้กำลังจะหมดเวลาในอีก \n นาที เพื่อที่จะหลีกเลี่ยงข้อขัดแย้งให้ใช้ปุ่ม "Preview" เพื่อรีเซ็ทเวลาใหม่';
 $lang['js']['notsavedyet']     = "การแก้ไขที่ไม่ได้บันทึกจะสูญหาย \n ต้องการทำต่อจริงๆหรือ?";
 $lang['rssfailed']             = 'มีข้อผิดพลาดขณะดูดฟีดนี้';
 $lang['nothingfound']          = 'ไม่พบสิ่งใด';
@@ -126,7 +124,6 @@ $lang['js']['nosmblinks']      = 'เชื่อมไปยังหน้า
 $lang['js']['linkwiz']         = 'ลิงค์วิเศษ';
 $lang['js']['linkto']          = 'ลิงค์ไป:';
 $lang['js']['del_confirm']     = 'ต้องการลบรายการที่เลือกจริงๆหรือ?';
-$lang['js']['mu_btn']          = 'อัพโหลดหลายๆไฟล์ในครั้งเดียว';
 $lang['mediausage']            = 'ให้ใช้ไวยกรณ์ต่อไปนี้เพื่ออ้างอิงไฟล์นี้';
 $lang['mediaview']             = 'ดูไฟล์ต้นฉบับ';
 $lang['mediaroot']             = 'ราก(รูท)';
@@ -224,21 +221,6 @@ $lang['i_pol0']                = 'วิกิเปิดกว้าง (ใ
 $lang['i_pol1']                = 'วิกิสาธารณะ (ทุกคนอ่านได้, เขียน และ อัพโหลดเฉพาะผู้ใช้ที่ลงทะเบียนแล้ว)';
 $lang['i_pol2']                = 'วิกิภายใน (อ่าน, เขียน, อัพโหลด สำหรับผู้ใช้ที่ลงทะเบียนแล้วเท่านั้น)';
 $lang['i_retry']               = 'ลองใหม่';
-$lang['mu_intro']              = 'ที่นี่คุณสามารถอัพโหลดหลายๆไฟล์ได้พร้อมๆกัน คลิ๊กปุ่มบราวซ์เพื่อเพิ่มมันเข้าไปในคิว กดปุ่มอัพโหลดเมื่อเสร็จแล้ว';
-$lang['mu_gridname']           = 'ชื่อไฟล์';
-$lang['mu_gridsize']           = 'ขนาด';
-$lang['mu_gridstat']           = 'สถานะ';
-$lang['mu_namespace']          = 'เนมสเปซ';
-$lang['mu_browse']             = 'เรียกดู';
-$lang['mu_toobig']             = 'ใหญ่ไป';
-$lang['mu_ready']              = 'พร้อมอัปโหลด';
-$lang['mu_done']               = 'เสร็จสิ้น';
-$lang['mu_fail']               = 'ล้มเหลว';
-$lang['mu_authfail']           = 'วาระหมดอายุ';
-$lang['mu_progress']           = '@PCT@% อัปโหลดแล้ว';
-$lang['mu_filetypes']          = 'ชนิดแฟ้มที่อนุญาต';
-$lang['mu_info']               = 'แฟ้มอัปโหลดแล้ว';
-$lang['mu_lasterr']            = 'ผิดพลาดล่าสุด:';
 $lang['years']                 = '%d ปีก่อน';
 $lang['months']                = '%d เดือนก่อน';
 $lang['weeks']                 = '%d สัปดาห์ก่อน';
