@@ -94,7 +94,7 @@ $lang['txt_filename']          = 'Завантажити як (не обов\'я
 $lang['txt_overwrt']           = 'Перезаписати існуючий файл';
 $lang['lockedby']              = 'Заблоковано';
 $lang['lockexpire']            = 'Блокування завершується в';
-$lang['willexpire']            = 'Блокування редагування цієї сторінки закінчується через хвилину.\n Щоб уникнути конфліктів використовуйте кнопку перегляду для продовження блокування.';
+$lang['js']['willexpire']            = 'Блокування редагування цієї сторінки закінчується через хвилину.\n Щоб уникнути конфліктів використовуйте кнопку перегляду для продовження блокування.';
 $lang['js']['notsavedyet']     = 'Незбережені зміни будуть втрачені.
  Дійсно продовжити?';
 $lang['js']['searchmedia']     = 'Шукати файли';
@@ -126,7 +126,6 @@ $lang['js']['nosmblinks']      = 'Посилання на мережеві па
 $lang['js']['linkwiz']         = 'Чарівник посилань';
 $lang['js']['linkto']          = 'Посилання на:';
 $lang['js']['del_confirm']     = 'Дійсно знищити обрані елементи?';
-$lang['js']['mu_btn']          = 'Завантажити одночасно кілька файлів';
 $lang['rssfailed']             = 'Виникла помилка під час отримання RSS-стрічки: ';
 $lang['nothingfound']          = 'Нічого не знайдено.';
 $lang['mediaselect']           = 'Вибір медіа-файлу';
@@ -264,21 +263,6 @@ $lang['i_pol1']                = 'Публічна Вікі (читання дл
 $lang['i_pol2']                = 'Закрита Вікі (читання, запис та завантаження тільки для зареєстрованих користувачів)';
 $lang['i_retry']               = 'Повторити';
 $lang['i_license']             = 'Будь ласка, виберіть тип ліцензії, під якою Ві бажаєте опублікувати матеріал:';
-$lang['mu_intro']              = 'Тут ви можете завантажити одночасно кілька файлів. Натисніть кнопку "Вибрати", щоб додати файли в чергу. Після закінчення натисніть кнопку "Завантажити"';
-$lang['mu_gridname']           = 'Ім’я файлу';
-$lang['mu_gridsize']           = 'Розмір';
-$lang['mu_gridstat']           = 'Статус';
-$lang['mu_namespace']          = 'Простір імен';
-$lang['mu_browse']             = 'Вибрати';
-$lang['mu_toobig']             = 'надто великий';
-$lang['mu_ready']              = 'готовий до завантаження';
-$lang['mu_done']               = 'закінчено';
-$lang['mu_fail']               = 'невдале';
-$lang['mu_authfail']           = 'закінчено термін дії сесії';
-$lang['mu_progress']           = 'Завантаження @PCT@%';
-$lang['mu_filetypes']          = 'Дозволені типи файлів';
-$lang['mu_info']               = 'Файли завантажено';
-$lang['mu_lasterr']            = 'Остання помилка:';
 $lang['recent_global']         = 'Ви переглядаєте зміни в межах простору імен <b>%s</b>. Також можна <a href="%s">переглянути зміни в межах усієї Вікі</a>.';
 $lang['years']                 = '%d років тому';
 $lang['months']                = '%d місяців тому';
