@@ -51,6 +51,8 @@ $lang['btn_recover']           = '復原草稿';
 $lang['btn_draftdel']          = '捨棄草稿';
 $lang['btn_revert']            = '復原';
 $lang['btn_register']          = '註冊';
+$lang['btn_apply']             = '套用';
+$lang['btn_media']             = '多媒體管理器';
 $lang['loggedinas']            = '登入為';
 $lang['user']                  = '帳號';
 $lang['pass']                  = '密碼';
@@ -95,7 +97,7 @@ $lang['txt_filename']          = '請輸入要存在維基內的檔案名稱 (
 $lang['txt_overwrt']           = '是否要覆蓋原有檔案';
 $lang['lockedby']              = '目前已被下列人員鎖定';
 $lang['lockexpire']            = '預計解除鎖定於';
-$lang['willexpire']            = '本頁的編輯鎖定將在一分鐘內到期。要避免發生衝突，請按「預覽」鍵重設鎖定計時。';
+$lang['js']['willexpire']      = '本頁的編輯鎖定將在一分鐘內到期。要避免發生衝突，請按「預覽」鍵重設鎖定計時。';
 $lang['js']['notsavedyet']     = '未儲存的變更將會遺失，繼續嗎？';
 $lang['js']['searchmedia']     = '搜尋檔案';
 $lang['js']['keepopen']        = '選擇時保持視窗開啟';
@@ -126,7 +128,17 @@ $lang['js']['nosmblinks']      = '只有在 Microsoft IE 下才能執行「連
 $lang['js']['linkwiz']         = '建立連結精靈';
 $lang['js']['linkto']          = '連結至：';
 $lang['js']['del_confirm']     = '確定刪除選取的項目？';
-$lang['js']['mu_btn']          = '上傳多個檔案';
+$lang['js']['restore_confirm'] = '確定還原到這個版本？';
+$lang['js']['media_diff']      = '檢視差異:';
+$lang['js']['media_diff_both'] = '並排';
+$lang['js']['media_diff_opacity'] = '重疊';
+$lang['js']['media_diff_portions'] = '滑動';
+$lang['js']['media_select']    = '選擇檔案…';
+$lang['js']['media_upload_btn'] = '上傳';
+$lang['js']['media_done_btn']  = '完成';
+$lang['js']['media_drop']      = '拖拉檔案到此上傳';
+$lang['js']['media_cancel']    = '刪除';
+$lang['js']['media_overwrt']   = '覆蓋已存在的檔案';
 $lang['rssfailed']             = '擷取 RSS 饋送檔時發生錯誤：';
 $lang['nothingfound']          = '沒找到任何結果。';
 $lang['mediaselect']           = '媒體檔案';
@@ -181,6 +193,10 @@ $lang['mail_changed']          = '變更的頁面:';
 $lang['mail_subscribe_list']   = '命名空間中更動的頁面:';
 $lang['mail_new_user']         = '新使用者:';
 $lang['mail_upload']           = '已上傳檔案:';
+$lang['changes_type']          = '檢視最近更新類型';
+$lang['pages_changes']         = '頁面';
+$lang['media_changes']         = '多媒體檔案';
+$lang['both_changes']          = '頁面和多媒體檔案';
 $lang['qb_bold']               = '粗體';
 $lang['qb_italic']             = '斜體';
 $lang['qb_underl']             = '底線';
@@ -221,6 +237,9 @@ $lang['img_copyr']             = '版權';
 $lang['img_format']            = '格式';
 $lang['img_camera']            = '相機';
 $lang['img_keywords']          = '關鍵字';
+$lang['img_width']             = '寬度';
+$lang['img_height']            = '高度';
+$lang['img_manager']           = '在多媒體管理器中檢視';
 $lang['subscr_subscribe_success'] = '已將 %s 加入至 %s 的訂閱列表';
 $lang['subscr_subscribe_error'] = '將 %s 加入至 %s 的訂閱列表時發生錯誤';
 $lang['subscr_subscribe_noaddress'] = '沒有與您登入相關的地址，無法將您加入訂閱列表';
@@ -263,21 +282,6 @@ $lang['i_pol1']                = '公開的維基 (任何人可讀取，註冊
 $lang['i_pol2']                = '封閉的維基 (只有註冊使用者可讀取、寫入、上傳)';
 $lang['i_retry']               = '重試';
 $lang['i_license']             = '請選擇您想要的內容發布許可協議：';
-$lang['mu_intro']              = '您可以在這裡一次上傳多個檔案。按下瀏覽按鈕加入檔案，然後按上傳按鈕開始上傳。';
-$lang['mu_gridname']           = '檔案名稱';
-$lang['mu_gridsize']           = '檔案大小';
-$lang['mu_gridstat']           = '狀態';
-$lang['mu_namespace']          = '命名空間';
-$lang['mu_browse']             = '瀏覽';
-$lang['mu_toobig']             = '太大';
-$lang['mu_ready']              = '準備上傳';
-$lang['mu_done']               = '完成';
-$lang['mu_fail']               = '失敗';
-$lang['mu_authfail']           = '作業階段逾時';
-$lang['mu_progress']           = '@PCT@% 已上傳';
-$lang['mu_filetypes']          = '接受的檔案類型';
-$lang['mu_info']               = '檔案已上傳。';
-$lang['mu_lasterr']            = '最新一筆錯誤紀錄：';
 $lang['recent_global']         = '您正在閱讀命名空間： <b>%s</b> 中的變更。您亦可觀看整個維基的<a href="%s">最近更新</a>。';
 $lang['years']                 = '%d 年前';
 $lang['months']                = '%d 個月前';
@@ -287,3 +291,27 @@ $lang['hours']                 = '%d 個小時前';
 $lang['minutes']               = '%d 分鐘前';
 $lang['seconds']               = '%s 秒鐘前';
 $lang['wordblock']             = '您的更改沒有被儲存，因为它包含被阻擋的文字 (垃圾訊息)。';
+$lang['media_uploadtab']       = '上傳';
+$lang['media_searchtab']       = '搜尋';
+$lang['media_file']            = '檔案';
+$lang['media_viewtab']         = '檢視';
+$lang['media_edittab']         = '編輯';
+$lang['media_historytab']      = '歷史紀錄';
+$lang['media_list_thumbs']     = '縮圖';
+$lang['media_list_rows']       = '列表';
+$lang['media_sort_name']       = '名稱';
+$lang['media_sort_date']       = '日期';
+$lang['media_namespaces']      = '選擇命名空間';
+$lang['media_files']           = '在 %s 中的檔案';
+$lang['media_upload']          = '上傳至 %s';
+$lang['media_search']          = '在 %s 中搜尋';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s 在 %s';
+$lang['media_edit']            = '編輯 %s';
+$lang['media_history']         = '%s 的歷史紀錄';
+$lang['media_meta_edited']     = '元資料已編輯';
+$lang['media_perm_read']       = '抱歉，您沒有足夠權限讀取檔案';
+$lang['media_perm_upload']     = '抱歉，您沒有足夠權限上傳檔案。';
+$lang['media_update']          = '上傳新的版本';
+$lang['media_restore']         = '還原這個版本';
+$lang['plugin_install_err']    = '插件安裝錯誤。將插件目錄 "%s" 重新命名為 "%s"';
