@@ -13,6 +13,8 @@
  * @author caii <zhoucaiqi@gmail.com>
  * @author Hiphen Lee <jacob.b.leung@gmail.com>
  * @author caii, patent agent in China <zhoucaiqi@gmail.com>
+ * @author lainme993@gmail.com
+ * @author Shuo-Ting Jian <shoting@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -54,6 +56,8 @@ $lang['btn_recover']           = '恢复草稿';
 $lang['btn_draftdel']          = '删除草稿';
 $lang['btn_revert']            = '恢复';
 $lang['btn_register']          = '注册';
+$lang['btn_apply']             = '应用';
+$lang['btn_media']             = '媒体管理器';
 $lang['loggedinas']            = '登录为';
 $lang['user']                  = '用户名';
 $lang['pass']                  = '密码';
@@ -98,7 +102,7 @@ $lang['txt_filename']          = '上传并重命名为（可选）';
 $lang['txt_overwrt']           = '覆盖已存在的同名文件';
 $lang['lockedby']              = '目前已被下列人员锁定';
 $lang['lockexpire']            = '预计锁定解除于';
-$lang['willexpire']            = '您对本页的独有编辑权将于一分钟之后解除。\n为了防止与其他人的编辑冲突，请使用预览按钮重设计时器。';
+$lang['js']['willexpire']      = '您对本页的独有编辑权将于一分钟之后解除。\n为了防止与其他人的编辑冲突，请使用预览按钮重设计时器。';
 $lang['js']['notsavedyet']     = '未保存的更改将丢失。
 真的要继续？';
 $lang['js']['searchmedia']     = '查找文件';
@@ -130,7 +134,17 @@ $lang['js']['nosmblinks']      = '连接到 Windows 共享功能只有在 IE 浏
 $lang['js']['linkwiz']         = '链接向导';
 $lang['js']['linkto']          = '链接到：';
 $lang['js']['del_confirm']     = '真的要删除选中的项目吗？';
-$lang['js']['mu_btn']          = '一次上传了多个文件';
+$lang['js']['restore_confirm'] = '确实要恢复这个版本么？';
+$lang['js']['media_diff']      = '查看差异：';
+$lang['js']['media_diff_both'] = '肩并肩';
+$lang['js']['media_diff_opacity'] = '叠加';
+$lang['js']['media_diff_portions'] = '滑块';
+$lang['js']['media_select']    = '选择文件……';
+$lang['js']['media_upload_btn'] = '上传';
+$lang['js']['media_done_btn']  = '完成';
+$lang['js']['media_drop']      = '拖拽文件到此处来上传';
+$lang['js']['media_cancel']    = '删除';
+$lang['js']['media_overwrt']   = '覆盖已存在的文件';
 $lang['rssfailed']             = '获取该 RSS 信息时产生错误：';
 $lang['nothingfound']          = '什么都没有找到。';
 $lang['mediaselect']           = '媒体文件';
@@ -185,6 +199,10 @@ $lang['mail_changed']          = '更改页面：';
 $lang['mail_subscribe_list']   = '命名空间中改变的页面：';
 $lang['mail_new_user']         = '新用户：';
 $lang['mail_upload']           = '已上传的文件：';
+$lang['changes_type']          = '查看何种更改';
+$lang['pages_changes']         = '页面';
+$lang['media_changes']         = '媒体文件';
+$lang['both_changes']          = '页面和媒体文件';
 $lang['qb_bold']               = '粗体';
 $lang['qb_italic']             = '斜体';
 $lang['qb_underl']             = '下划线';
@@ -225,6 +243,9 @@ $lang['img_copyr']             = '版权';
 $lang['img_format']            = '格式';
 $lang['img_camera']            = '相机';
 $lang['img_keywords']          = '关键字';
+$lang['img_width']             = '宽度';
+$lang['img_height']            = '高度';
+$lang['img_manager']           = '在媒体管理器中查看';
 $lang['subscr_subscribe_success'] = '添加 %s 到 %s 的订阅列表';
 $lang['subscr_subscribe_error'] = '添加 %s 到 %s 的订阅列表中出现错误';
 $lang['subscr_subscribe_noaddress'] = '没有与您登录信息相关联的地址，您无法被添加到订阅列表';
@@ -269,21 +290,7 @@ $lang['i_pol1']                = '公共的维基（任何人都有读的权限
 $lang['i_pol2']                = '关闭的维基（只有注册用户才有读、写、上传的权限）';
 $lang['i_retry']               = '重试';
 $lang['i_license']             = '请选择您希望的内容发布许可协议：';
-$lang['mu_intro']              = '您可以在此一次上传多个文件。点按浏览按钮添加文件到上传队列中，先好后按上传钮。';
-$lang['mu_gridname']           = '文件名';
-$lang['mu_gridsize']           = '大小';
-$lang['mu_gridstat']           = '状态';
-$lang['mu_namespace']          = '名称空间';
-$lang['mu_browse']             = '浏览';
-$lang['mu_toobig']             = '过大';
-$lang['mu_ready']              = '准备好上传';
-$lang['mu_done']               = '完成';
-$lang['mu_fail']               = '失败';
-$lang['mu_authfail']           = '会话过期';
-$lang['mu_progress']           = '@PCT@% 上传完成';
-$lang['mu_filetypes']          = '允许的文件类型';
-$lang['mu_info']               = '文件已上传。';
-$lang['mu_lasterr']            = '最后一个错误：';
+
 $lang['recent_global']         = '您当前看到的是<b>%s</b> 名称空间的变动。你还可以在<a href="%s">查看整个维基的近期变动</a>。';
 $lang['years']                 = '%d年前';
 $lang['months']                = '%d月前';
@@ -293,3 +300,27 @@ $lang['hours']                 = '%d小时前';
 $lang['minutes']               = '%d分钟前';
 $lang['seconds']               = '%d秒前';
 $lang['wordblock']             = '您的更改没有被保存，因为它包含被屏蔽的文字（垃圾信息）。';
+$lang['media_uploadtab']       = '上传';
+$lang['media_searchtab']       = '搜索';
+$lang['media_file']            = '文件';
+$lang['media_viewtab']         = '查看';
+$lang['media_edittab']         = '编辑';
+$lang['media_historytab']      = '历史';
+$lang['media_list_thumbs']     = '缩图';
+$lang['media_list_rows']       = '列表';
+$lang['media_sort_name']       = '按名称';
+$lang['media_sort_date']       = '按日期';
+$lang['media_namespaces']      = '选择命名空间';
+$lang['media_files']           = '在 %s 中的文件';
+$lang['media_upload']          = '上传到 <strong>%s</strong> 命名空间。';
+$lang['media_search']          = '在 <strong>%s</strong> 命名空间中搜索。';
+$lang['media_view']            = '%s 在 %s';
+$lang['media_viewold']         = '%s ';
+$lang['media_edit']            = '编辑 %s';
+$lang['media_history']         = '%s 的历史纪录';
+$lang['media_meta_edited']     = '元数据已编辑';
+$lang['media_perm_read']       = '抱歉，您没有足够权限读取这些文件。';
+$lang['media_perm_upload']     = '抱歉，您没有足够权限来上传文件。';
+$lang['media_update']          = '上传新版本';
+$lang['media_restore']         = '恢复这个版本';
+$lang['plugin_install_err']    = '插件安装不正确。重命名插件目录“%s”为“%s”。';
