@@ -103,12 +103,13 @@ $lang['fetchsize']             = 'بیشینه‌ی حجمی که فایل fetch
 $lang['notify']                = 'تغییرات به این ایمیل ارسال شود';
 $lang['registernotify']        = 'اطلاعات کاربران تازه وارد به این ایمیل ارسال شود';
 $lang['mailfrom']              = 'آدرس ایمیلی که برای ایمیل‌های خودکار استفاده می‌شود';
-$lang['mailprefix']            = 'پیشوند عنوان رای‌نامه، برای رای‌نامه‌های خودکار';
+$lang['mailprefix']            = 'پیشوند تیتر ایمیل (جهت ایمیل های خودکار)';
 $lang['gzip_output']           = 'استفاده از gzip برای xhtmlها';
 $lang['gdlib']                 = 'نگارش کتاب‌خانه‌ی GD';
 $lang['im_convert']            = 'مسیر ابزار convert از برنامه‌ی ImageMagick';
 $lang['jpg_quality']           = 'کیفیت فشرده سازی JPEG (از 0 تا 100)';
 $lang['subscribers']           = 'توانایی عضویت در صفحات باشد';
+$lang['subscribe_time']        = 'زمان مورد نیاز برای ارسال خبر نامه ها (ثانیه); این مقدار می بایست کمتر زمانی باشد که در recent_days تعریف شده است.';
 $lang['compress']              = 'فشرده‌سازی کد‌های CSS و JavaScript';
 $lang['hidepages']             = 'مخفی کردن صفحات با فرمت زیر (از عبارات منظم استفاده شود)';
 $lang['send404']               = 'ارسال «HTTP 404/Page Not Found» برای صفحاتی که وجود ندارند';
