@@ -44,6 +44,7 @@ $lang['lang']                  = '語系';
 $lang['basedir']               = '根目錄';
 $lang['baseurl']               = '根路徑 (URL)';
 $lang['savedir']               = '儲存資料的目錄';
+$lang['cookiedir']             = 'Cookie 路徑。設定空白則使用 baseurl。';
 $lang['start']                 = '開始頁面的名稱';
 $lang['title']                 = '維基標題';
 $lang['template']              = '樣板';
@@ -114,6 +115,7 @@ $lang['jpg_quality']           = 'JPG 壓縮品質(0-100)';
 $lang['subscribers']           = '啟用頁面訂閱';
 $lang['subscribe_time']        = '訂閱列表和摘要發送的時間間隔 (秒)；這個值應該小於指定的最近更改保留時間 (recent_days)。';
 $lang['compress']              = '壓縮 CSS 與 JavaScript 的輸出';
+$lang['cssdatauri']            = 'CSS 中所引用的圖片假如小於該數字大小(bytes)，將會被直接嵌入 CSS 中來減少 HTTP Request 的發送。此功能在 IE 7 及之下版本不支援。推薦使用 <code>400</code> 到 <code>600</code> 之間。設定為<code>0</code> 則停用。';
 $lang['hidepages']             = '隱藏匹配的界面 (正規式)';
 $lang['send404']               = '存取不存在的頁面時送出 "HTTP 404/Page Not Found"';
 $lang['sitemap']               = '產生 Google 站台地圖 (天)';
